@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "crystaltools.h"
@@ -22,8 +11,7 @@
 #include <algorithm>
 #include <iostream>
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 namespace {
 struct WrapAtomsToCellFunctor
@@ -442,9 +430,8 @@ bool CrystalTools::niggliReduce(Molecule& molecule, Options opts)
 
     // fix coordinates with COB matrix:
     const Matrix3 invCob(cob.inverse());
-    for (Array<Vector3>::iterator it = fcoords.begin(), itEnd = fcoords.end();
-         it != itEnd; ++it) {
-      *it = invCob * (*it);
+    for (auto & fcoord : fcoords) {
+      fcoord = invCob * fcoord;
     }
 
     // Update cell
@@ -694,5 +681,4 @@ bool CrystalTools::setFractionalCoordinates(Molecule& molecule,
   return true;
 }
 
-} // namespace Core
 } // namespace Avogadro
