@@ -1,18 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2008-2009 Marcus D. Hanwell
-  Copyright 2010-2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "cube.h"
@@ -20,8 +8,7 @@
 #include "molecule.h"
 #include "mutex.h"
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 Cube::Cube()
   : m_data(0), m_min(0.0, 0.0, 0.0), m_max(0.0, 0.0, 0.0),
@@ -51,14 +38,14 @@ bool Cube::setLimits(const Vector3& min_, const Vector3& max_,
   return true;
 }
 
-bool Cube::setLimits(const Vector3& min_, const Vector3& max_, double spacing_)
+bool Cube::setLimits(const Vector3& min_, const Vector3& max_, float spacing_)
 {
   Vector3 delta = max_ - min_;
   delta = delta / spacing_;
   return setLimits(min_, max_, delta.cast<int>());
 }
 
-bool Cube::setLimits(const Vector3& min_, const Vector3i& dim, double spacing_)
+bool Cube::setLimits(const Vector3& min_, const Vector3i& dim, float spacing_)
 {
   return setLimits(min_, dim, Vector3(spacing_, spacing_, spacing_));
 }
@@ -87,7 +74,7 @@ bool Cube::setLimits(const Cube& cube)
   return true;
 }
 
-bool Cube::setLimits(const Molecule& mol, double spacing_, double padding)
+bool Cube::setLimits(const Molecule& mol, float spacing_, float padding)
 {
   Index numAtoms = mol.atomCount();
   Vector3 min_, max_;
@@ -119,17 +106,17 @@ bool Cube::setLimits(const Molecule& mol, double spacing_, double padding)
   return setLimits(min_, max_, spacing_);
 }
 
-std::vector<double>* Cube::data()
+std::vector<float>* Cube::data()
 {
   return &m_data;
 }
 
-const std::vector<double>* Cube::data() const
+const std::vector<float>* Cube::data() const
 {
   return &m_data;
 }
 
-bool Cube::setData(const std::vector<double>& values)
+bool Cube::setData(const std::vector<float>& values)
 {
   if (!values.size())
     return false;
@@ -139,12 +126,11 @@ bool Cube::setData(const std::vector<double>& values)
     m_data = values;
     // Now to update the minimum and maximum values
     m_minValue = m_maxValue = m_data[0];
-    for (std::vector<double>::const_iterator it = values.begin();
-         it != values.end(); ++it) {
-      if (*it < m_minValue)
-        m_minValue = *it;
-      else if (*it > m_maxValue)
-        m_maxValue = *it;
+    for (float value : values) {
+      if (value < m_minValue)
+        m_minValue = value;
+      else if (value > m_maxValue)
+        m_maxValue = value;
     }
     return true;
   } else {
@@ -152,7 +138,7 @@ bool Cube::setData(const std::vector<double>& values)
   }
 }
 
-bool Cube::addData(const std::vector<double>& values)
+bool Cube::addData(const std::vector<float>& values)
 {
   // Initialise the cube to zero if necessary
   if (!m_data.size())
@@ -199,7 +185,7 @@ Vector3 Cube::position(unsigned int index) const
                  z * m_spacing.z() + m_min.z());
 }
 
-double Cube::value(int i, int j, int k) const
+float Cube::value(int i, int j, int k) const
 {
   unsigned int index = i * m_points.y() * m_points.z() + j * m_points.z() + k;
   if (index < m_data.size())
@@ -208,7 +194,7 @@ double Cube::value(int i, int j, int k) const
     return 0.0;
 }
 
-double Cube::value(const Vector3i& pos) const
+float Cube::value(const Vector3i& pos) const
 {
   unsigned int index =
     pos.x() * m_points.y() * m_points.z() + pos.y() * m_points.z() + pos.z();
@@ -248,7 +234,7 @@ float Cube::valuef(const Vector3f& pos) const
     value(hC.x(), hC.y(), hC.z()) * P.x() * P.y() * P.z());
 }
 
-double Cube::value(const Vector3& pos) const
+float Cube::value(const Vector3& pos) const
 {
   // This is a really expensive operation and so should be avoided
   // Interpolate the value at the supplied vector - trilinear interpolation...
@@ -275,20 +261,37 @@ double Cube::value(const Vector3& pos) const
          value(hC.x(), hC.y(), hC.z()) * P.x() * P.y() * P.z();
 }
 
-bool Cube::setValue(int i, int j, int k, double value_)
+bool Cube::setValue(unsigned int i, unsigned int j, unsigned int k, float value_)
 {
   unsigned int index = i * m_points.y() * m_points.z() + j * m_points.z() + k;
-  if (index < m_data.size()) {
-    m_data[index] = value_;
-    if (value_ < m_minValue)
-      m_minValue = value_;
-    else if (value_ > m_maxValue)
-      m_maxValue = value_;
-    return true;
-  } else {
+  if (index >= m_data.size())
     return false;
-  }
+  m_data[index] = value_;
+  if (value_ < m_minValue)
+    m_minValue = value_;
+  else if (value_ > m_maxValue)
+    m_maxValue = value_;
+  return true;
+}
+
+void Cube::fill(float value_)
+{
+  std::fill(m_data.begin(), m_data.end(), value_);
+  m_minValue = m_maxValue = value_;
+}
+
+bool Cube::fillStripe(
+  unsigned int i, unsigned int j, unsigned int kfirst, unsigned int klast, float value_
+) {
+  unsigned int stripeStartIndex = i * m_points.y() * m_points.z() + j * m_points.z();
+  unsigned int firstIndex = stripeStartIndex + kfirst;
+  if (firstIndex >= m_data.size())
+    return false;
+  unsigned int lastIndex = stripeStartIndex + klast;
+  if (lastIndex >= m_data.size())
+    return false;
+  std::fill(&m_data[firstIndex], &m_data[lastIndex+1], value_);
+  return true;
 }
 
-} // End Core namespace
 } // End Avogadro namespace
