@@ -9,10 +9,13 @@
 #include "color3f.h"
 #include "cube.h"
 #include "elements.h"
+#include "gaussianset.h"
 #include "layermanager.h"
+#include "mdlvalence_p.h"
 #include "mesh.h"
 #include "neighborperceiver.h"
 #include "residue.h"
+#include "slaterset.h"
 #include "unitcell.h"
 
 #include <algorithm>
@@ -33,9 +36,10 @@ Molecule::Molecule()
 
 Molecule::Molecule(const Molecule& other)
   : m_data(other.m_data), m_partialCharges(other.m_partialCharges),
-    m_customElementMap(other.m_customElementMap), m_elements(other.m_elements),
-    m_positions2d(other.m_positions2d), m_positions3d(other.m_positions3d),
-    m_label(other.m_label), m_coordinates3d(other.m_coordinates3d),
+    m_spectra(other.m_spectra), m_customElementMap(other.m_customElementMap),
+    m_elements(other.m_elements), m_positions2d(other.m_positions2d),
+    m_positions3d(other.m_positions3d), m_atomLabels(other.m_atomLabels),
+    m_bondLabels(other.m_bondLabels), m_coordinates3d(other.m_coordinates3d),
     m_timesteps(other.m_timesteps), m_hybridizations(other.m_hybridizations),
     m_formalCharges(other.m_formalCharges), m_colors(other.m_colors),
     m_vibrationFrequencies(other.m_vibrationFrequencies),
@@ -45,9 +49,10 @@ Molecule::Molecule(const Molecule& other)
     m_meshes(std::vector<Mesh*>()), m_cubes(std::vector<Cube*>()),
     m_basisSet(other.m_basisSet ? other.m_basisSet->clone() : nullptr),
     m_unitCell(other.m_unitCell ? new UnitCell(*other.m_unitCell) : nullptr),
-    m_residues(other.m_residues), m_graph(other.m_graph),
-    m_bondOrders(other.m_bondOrders), m_atomicNumbers(other.m_atomicNumbers),
-    m_hallNumber(other.m_hallNumber),
+    m_residues(other.m_residues), m_hallNumber(other.m_hallNumber),
+    m_graph(other.m_graph), m_bondOrders(other.m_bondOrders),
+    m_atomicNumbers(other.m_atomicNumbers),
+    m_frozenAtomMask(other.m_frozenAtomMask),
     m_layers(LayerManager::getMoleculeLayer(this))
 {
   // Copy over any meshes
@@ -72,28 +77,78 @@ Molecule::Molecule(const Molecule& other)
   }
 }
 
+void Molecule::readProperties(const Molecule& other)
+{
+  m_atomLabels = other.m_atomLabels;
+  m_bondLabels = other.m_bondLabels;
+  m_colors = other.m_colors;
+  // merge data maps by iterating through other's map
+  for (auto it = other.m_data.constBegin(); it != other.m_data.constEnd();
+       ++it) {
+    // even if we have the same key, we want to overwrite
+    m_data.setValue(it->first, it->second);
+  }
+  // merge partial charge maps
+  for (auto it = other.m_partialCharges.cbegin();
+       it != other.m_partialCharges.cend(); ++it) {
+    m_partialCharges[it->first] = it->second;
+  }
+
+  // copy spectra
+  m_spectra = other.m_spectra;
+
+  // copy orbital information
+  SlaterSet* slaterSet = dynamic_cast<SlaterSet*>(other.m_basisSet);
+  if (slaterSet != nullptr) {
+    m_basisSet = slaterSet->clone();
+    m_basisSet->setMolecule(this);
+  }
+  GaussianSet* gaussianSet = dynamic_cast<GaussianSet*>(other.m_basisSet);
+  if (gaussianSet != nullptr) {
+    m_basisSet = gaussianSet->clone();
+    m_basisSet->setMolecule(this);
+  }
+
+  // copy over spectra information
+  if (other.m_vibrationFrequencies.size() > 0) {
+    m_vibrationFrequencies = other.m_vibrationFrequencies;
+    m_vibrationIRIntensities = other.m_vibrationIRIntensities;
+    m_vibrationRamanIntensities = other.m_vibrationRamanIntensities;
+    m_vibrationLx = other.m_vibrationLx;
+  }
+
+  // Copy over any meshes
+  for (Index i = 0; i < other.meshCount(); ++i) {
+    Mesh* m = addMesh();
+    *m = *other.mesh(i);
+  }
+
+  // Copy over any cubes
+  for (Index i = 0; i < other.cubeCount(); ++i) {
+    Cube* c = addCube();
+    *c = *other.cube(i);
+  }
+}
+
 Molecule::Molecule(Molecule&& other) noexcept
-  : m_data(other.m_data),
-    m_partialCharges(std::move(other.m_partialCharges)),
+  : m_data(other.m_data), m_partialCharges(std::move(other.m_partialCharges)),
+    m_spectra(other.m_spectra),
     m_customElementMap(std::move(other.m_customElementMap)),
     m_elements(other.m_elements), m_positions2d(other.m_positions2d),
-    m_positions3d(other.m_positions3d),
-    m_label(other.m_label),
-    m_coordinates3d(other.m_coordinates3d),
-    m_timesteps(other.m_timesteps),
-    m_hybridizations(other.m_hybridizations),
-    m_formalCharges(other.m_formalCharges),
-    m_colors(other.m_colors),
+    m_positions3d(other.m_positions3d), m_atomLabels(other.m_atomLabels),
+    m_bondLabels(other.m_bondLabels), m_coordinates3d(other.m_coordinates3d),
+    m_timesteps(other.m_timesteps), m_hybridizations(other.m_hybridizations),
+    m_formalCharges(other.m_formalCharges), m_colors(other.m_colors),
     m_vibrationFrequencies(other.m_vibrationFrequencies),
     m_vibrationIRIntensities(other.m_vibrationIRIntensities),
     m_vibrationRamanIntensities(other.m_vibrationRamanIntensities),
     m_vibrationLx(other.m_vibrationLx),
     m_selectedAtoms(std::move(other.m_selectedAtoms)),
     m_meshes(std::move(other.m_meshes)), m_cubes(std::move(other.m_cubes)),
-    m_residues(other.m_residues), m_graph(other.m_graph),
-    m_bondOrders(other.m_bondOrders),
+    m_residues(other.m_residues), m_hallNumber(other.m_hallNumber),
+    m_graph(other.m_graph), m_bondOrders(other.m_bondOrders),
     m_atomicNumbers(other.m_atomicNumbers),
-    m_hallNumber(other.m_hallNumber),
+    m_frozenAtomMask(other.m_frozenAtomMask),
     m_layers(LayerManager::getMoleculeLayer(this))
 {
   m_basisSet = other.m_basisSet;
@@ -117,11 +172,13 @@ Molecule& Molecule::operator=(const Molecule& other)
   if (this != &other) {
     m_data = other.m_data;
     m_partialCharges = other.m_partialCharges;
+    m_spectra = other.m_spectra;
     m_customElementMap = other.m_customElementMap;
     m_elements = other.m_elements;
     m_positions2d = other.m_positions2d;
     m_positions3d = other.m_positions3d;
-    m_label = other.m_label;
+    m_atomLabels = other.m_atomLabels;
+    m_bondLabels = other.m_bondLabels;
     m_coordinates3d = other.m_coordinates3d;
     m_timesteps = other.m_timesteps;
     m_hybridizations = other.m_hybridizations;
@@ -137,6 +194,7 @@ Molecule& Molecule::operator=(const Molecule& other)
     m_bondOrders = other.m_bondOrders;
     m_atomicNumbers = other.m_atomicNumbers;
     m_hallNumber = other.m_hallNumber;
+    m_frozenAtomMask = other.m_frozenAtomMask;
 
     clearMeshes();
 
@@ -177,11 +235,13 @@ Molecule& Molecule::operator=(Molecule&& other) noexcept
   if (this != &other) {
     m_data = other.m_data;
     m_partialCharges = std::move(other.m_partialCharges);
+    m_spectra = other.m_spectra;
     m_customElementMap = std::move(other.m_customElementMap);
     m_elements = other.m_elements;
     m_positions2d = other.m_positions2d;
     m_positions3d = other.m_positions3d;
-    m_label = other.m_label;
+    m_atomLabels = other.m_atomLabels;
+    m_bondLabels = other.m_bondLabels;
     m_coordinates3d = other.m_coordinates3d;
     m_timesteps = other.m_timesteps;
     m_hybridizations = other.m_hybridizations;
@@ -197,6 +257,7 @@ Molecule& Molecule::operator=(Molecule&& other) noexcept
     m_bondOrders = other.m_bondOrders;
     m_atomicNumbers = other.m_atomicNumbers;
     m_hallNumber = other.m_hallNumber;
+    m_frozenAtomMask = other.m_frozenAtomMask;
 
     clearMeshes();
     m_meshes = std::move(other.m_meshes);
@@ -245,7 +306,7 @@ const Layer& Molecule::layer() const
 
 void Molecule::setPartialCharges(const std::string& type, const MatrixX& value)
 {
-  if (value.size() != atomCount())
+  if (static_cast<Index>(value.size()) != atomCount())
     return;
 
   m_partialCharges[type] = value;
@@ -271,6 +332,83 @@ std::set<std::string> Molecule::partialChargeTypes() const
   return types;
 }
 
+std::set<std::string> Molecule::spectraTypes() const
+{
+  std::set<std::string> types;
+  for (auto& it : m_spectra)
+    types.insert(it.first);
+  return types;
+}
+
+void Molecule::setSpectra(const std::string& type, const MatrixX& value)
+{
+  m_spectra[type] = value;
+}
+
+MatrixX Molecule::spectra(const std::string& type) const
+{
+  MatrixX value;
+
+  auto search = m_spectra.find(type);
+  if (search != m_spectra.end()) {
+    value = search->second; // value from the map
+  }
+
+  return value;
+}
+
+void Molecule::setFrozenAtom(Index atomId, bool frozen)
+{
+  if (atomId >= m_atomicNumbers.size())
+    return;
+
+  // check if we need to resize
+  unsigned int size = m_frozenAtomMask.rows();
+  if (m_frozenAtomMask.rows() != 3 * m_atomicNumbers.size())
+    m_frozenAtomMask.conservativeResize(3 * m_atomicNumbers.size());
+
+  // do we need to initialize new values?
+  if (m_frozenAtomMask.rows() > size)
+    for (unsigned int i = size; i < m_frozenAtomMask.rows(); ++i)
+      m_frozenAtomMask[i] = 1.0;
+
+  float value = frozen ? 0.0 : 1.0;
+  if (atomId * 3 <= m_frozenAtomMask.rows() - 3) {
+    m_frozenAtomMask[atomId * 3] = value;
+    m_frozenAtomMask[atomId * 3 + 1] = value;
+    m_frozenAtomMask[atomId * 3 + 2] = value;
+  }
+}
+
+bool Molecule::frozenAtom(Index atomId) const
+{
+  bool frozen = false;
+  if (atomId * 3 <= m_frozenAtomMask.rows() - 3) {
+    frozen = (m_frozenAtomMask[atomId * 3] == 0.0 &&
+              m_frozenAtomMask[atomId * 3 + 1] == 0.0 &&
+              m_frozenAtomMask[atomId * 3 + 2] == 0.0);
+  }
+  return frozen;
+}
+
+void Molecule::setFrozenAtomAxis(Index atomId, int axis, bool frozen)
+{
+  // check if we need to resize
+  unsigned int size = m_frozenAtomMask.rows();
+  if (m_frozenAtomMask.rows() != 3 * m_atomicNumbers.size())
+    m_frozenAtomMask.conservativeResize(3 * m_atomicNumbers.size());
+
+  // do we need to initialize new values?
+  if (m_frozenAtomMask.rows() > size)
+    for (unsigned int i = size; i < m_frozenAtomMask.rows(); ++i)
+      m_frozenAtomMask[i] = 1.0;
+
+  float value = frozen ? 0.0 : 1.0;
+  if (atomId * 3 <= m_frozenAtomMask.rows() - 3) {
+    m_frozenAtomMask[atomId * 3 + axis] = value;
+  }
+}
+
 void Molecule::setData(const std::string& name, const Variant& value)
 {
   m_data.setValue(name, value);
@@ -321,6 +459,50 @@ const Array<signed char>& Molecule::formalCharges() const
   return m_formalCharges;
 }
 
+signed char Molecule::totalCharge() const
+{
+  signed char charge = 0;
+
+  // check the data map first
+  if (m_data.hasValue("totalCharge")) {
+    charge = m_data.value("totalCharge").toInt();
+  } else if (m_formalCharges.size() > 0) {
+    for (Index i = 0; i < m_formalCharges.size(); ++i)
+      charge += m_formalCharges[i];
+    return charge;
+  }
+  return charge; // should be zero
+}
+
+char Molecule::totalSpinMultiplicity() const
+{
+  char spin = 1;
+
+  // check the data map first
+  if (m_data.hasValue("totalSpinMultiplicity")) {
+    spin = m_data.value("totalSpinMultiplicity").toInt();
+  } else {
+    // add up the electrons
+    unsigned long electrons = 0;
+    for (Index i = 0; i < m_atomicNumbers.size(); ++i)
+      electrons += m_atomicNumbers[i];
+
+    // adjust by the total charge
+    electrons -= totalCharge();
+
+    // if there are an even number of electrons, the spin is 1
+    // if there are an odd number of electrons, the spin is 2
+    // (might not be true, but a good default for many molecules)
+    // %todo - adjust for inorganic / organometallics
+    if (electrons % 2 == 0)
+      spin = 1;
+    else
+      spin = 2;
+  }
+
+  return spin; // should be zero
+}
+
 Array<Vector3ub>& Molecule::colors()
 {
   return m_colors;
@@ -467,12 +649,13 @@ void Molecule::clearAtoms()
 {
   m_positions2d.clear();
   m_positions3d.clear();
-  m_label.clear();
+  m_atomLabels.clear();
   m_hybridizations.clear();
   m_formalCharges.clear();
   m_colors.clear();
   m_atomicNumbers.clear();
   m_bondOrders.clear();
+  m_bondLabels.clear();
   m_graph.clear();
   m_partialCharges.clear();
   m_elements.reset();
@@ -514,7 +697,7 @@ Molecule::BondType Molecule::addBond(const AtomType& a, const AtomType& b,
 size_t calcNlogN(size_t n)
 {
   size_t aproxLog = 1;
-  float aux = n;
+  float aux = static_cast<float>(n);
   while (aux > 2.0f) {
     aux /= 2.0f;
     ++aproxLog;
@@ -607,8 +790,8 @@ Array<const Molecule::BondType*> Molecule::bonds(Index a) const
   }
 
   std::sort(atomBonds.begin(), atomBonds.end(),
-            [](const BondType*& a, const BondType*& b) {
-              return a->index() < b->index();
+            [](const BondType*& ba, const BondType*& bb) {
+              return ba->index() < bb->index();
             });
   return atomBonds;
 }
@@ -626,7 +809,7 @@ Array<Molecule::BondType> Molecule::bonds(Index a)
   }
 
   std::sort(atomBonds.begin(), atomBonds.end(),
-            [](BondType& a, BondType& b) { return a.index() < b.index(); });
+            [](BondType& ba, BondType& bb) { return ba.index() < bb.index(); });
   return atomBonds;
 }
 
@@ -846,6 +1029,143 @@ void Molecule::setVibrationLx(const Array<Array<Vector3>>& lx)
   m_vibrationLx = lx;
 }
 
+void Molecule::perceiveBondOrders()
+{
+  // check for coordinates and that there are some bonds
+  if (m_positions3d.size() != atomCount() || m_positions3d.size() < 2 ||
+      m_graph.edgeCount() == 0)
+    return;
+
+  // save the existing bonds and bond orders
+  // first calculate the unsaturated valence for every atom
+  Array<unsigned char> originalBonds = m_bondOrders;
+  Array<unsigned char> unsaturatedValence(atomCount(), 0);
+  bool anyUnsaturated = false;
+  for (Index i = 0; i < atomCount(); ++i) {
+    unsigned char boSum = 0;
+    for (auto bond : bonds(i)) {
+      boSum += bond.order();
+    }
+    unsaturatedValence[i] =
+      atomValence(atomicNumber(i), formalCharge(i), bonds(i).size()) - boSum;
+
+    if (unsaturatedValence[i] > 0)
+      anyUnsaturated = true;
+  }
+
+  Index startIndex = 0;
+  Index initialAtom = 0;
+  while (anyUnsaturated) {
+
+    // okay, we're first going to try placing *one* bond from our start atom
+    // .. then we can try placing bonds anywhere
+
+    // find the first atom with unsaturated valence of ONE
+    bool foundStart = false;
+    for (Index i = startIndex; i < atomCount(); ++i) {
+      if (unsaturatedValence[i] == 1) {
+        startIndex = i;
+        foundStart = true;
+        break;
+      }
+    }
+
+    // if we didn't find an atom with unsaturated valence of ONE,
+    // .. then find *something*
+    if (!foundStart) {
+      for (Index i = startIndex; i < atomCount(); ++i) {
+        if (unsaturatedValence[i] > 0) {
+          startIndex = i;
+          foundStart = true;
+          break;
+        }
+      }
+    }
+
+    if (foundStart) {
+      // std::cerr << "Found start index " << startIndex << std::endl;
+
+      // look at the neighbors of our start atom
+      Index bestIndex = MaxIndex;
+      unsigned bestValence = 256; // something impossible
+      Real bestDistance = 100.0;  // 10 Angstroms squared
+      Vector3 startPosition = m_positions3d[startIndex];
+      // iterate through the Indexes of the neighbors
+      for (auto neighbor : graph().neighbors(startIndex)) {
+        // if this neighbor doesn't have an unsaturated valence, skip it
+        if (unsaturatedValence[neighbor] == 0) {
+          continue;
+        }
+
+        if (unsaturatedValence[neighbor] < bestValence) {
+          bestIndex = neighbor;
+          bestValence = unsaturatedValence[neighbor];
+          bestDistance =
+            (m_positions3d[neighbor] - startPosition).squaredNorm();
+        } else if (unsaturatedValence[neighbor] == bestValence) {
+          // check if this neighbor is closer
+          Real distance =
+            (m_positions3d[neighbor] - startPosition).squaredNorm();
+          if (distance < bestDistance) {
+            bestIndex = neighbor;
+            bestDistance = distance;
+          }
+        }
+      }
+      // if we found a neighbor, then we can assign a bond order and update
+      // charges
+      if (bestIndex != MaxIndex) {
+        /*std::cerr << "Assigning bond " << startIndex << " " << bestIndex
+                  << std::endl; */
+
+        // assign the bond order
+        m_bondOrders[bond(startIndex, bestIndex).index()] += 1;
+        // update the unsaturated valence of the start atom
+        unsaturatedValence[startIndex] -= 1;
+        // update the unsaturated valence of the neighbor atom
+        unsaturatedValence[bestIndex] -= 1;
+
+        startIndex = 0; // we can now try placing bonds anywhere
+      } else {
+        startIndex += 1;
+      }
+    }
+
+    // TODO: update the current formal charges
+
+    anyUnsaturated = false; // check if we're done
+    for (Index i = 0; i < atomCount(); ++i) {
+      if (unsaturatedValence[i] > 0) {
+        anyUnsaturated = true;
+        break;
+      }
+    }
+
+    if (!foundStart && anyUnsaturated) {
+      // we've gone through and it's not working
+      // try a new starting atom and reset the bond orders
+      // std::cerr << " didn't work " << initialAtom << std::endl;
+
+      initialAtom += 1;
+      startIndex = initialAtom;
+      for (Index i = 0; i < m_bondOrders.size(); ++i) {
+        unsigned change = m_bondOrders[i] - originalBonds[i];
+        if (change > 0) {
+          // update the valences
+          unsaturatedValence[bond(i).atom1().index()] += change;
+          unsaturatedValence[bond(i).atom2().index()] += change;
+        }
+        m_bondOrders[i] = originalBonds[i];
+      }
+    }
+
+    if (initialAtom >= atomCount()) {
+      break;
+    }
+
+  } // keep going until we've assigned all the bond orders
+}
+
 void Molecule::perceiveBondsSimple(const double tolerance, const double min)
 {
   // check for coordinates
@@ -878,6 +1198,28 @@ void Molecule::perceiveBondsSimple(const double tolerance, const double min)
       Vector3 jpos = m_positions3d[j];
       Vector3 diff = jpos - ipos;
 
+      // Don't automatically bond nobel gases to anything
+      switch (atomicNumber(i)) {
+        case 2:  // He
+        case 10: // Ne
+        case 18: // Ar
+        case 36: // Kr
+          continue;
+        default:
+          break;
+      }
+
+      // now for the other atom
+      switch (atomicNumber(j)) {
+        case 2:  // He
+        case 10: // Ne
+        case 18: // Ar
+        case 36: // Kr
+          continue;
+        default:
+          break;
+      }
+
       if (std::fabs(diff[0]) > cutoff || std::fabs(diff[1]) > cutoff ||
           std::fabs(diff[2]) > cutoff ||
           (atomicNumber(i) == 1 && atomicNumber(j) == 1))
@@ -894,7 +1236,7 @@ void Molecule::perceiveBondsSimple(const double tolerance, const double min)
 
 void Molecule::perceiveBondsFromResidueData()
 {
-  for (auto & m_residue : m_residues) {
+  for (auto& m_residue : m_residues) {
     m_residue.resolveResidueBonds(*this);
   }
 }
@@ -913,6 +1255,11 @@ bool Molecule::setCoordinate3d(int coord)
   return false;
 }
 
+void Molecule::clearCoordinate3d()
+{
+  m_coordinates3d.clear();
+}
+
 Array<Vector3> Molecule::coordinate3d(int index) const
 {
   return m_coordinates3d[index];
@@ -1147,4 +1494,29 @@ std::list<Index> Molecule::getAtomsAtLayer(size_t layer)
   return result;
 }
 
-} // namespace Avogadro
+void Molecule::boundingBox(Vector3& boxMin, Vector3& boxMax,
+                           const double radius) const
+{
+  boxMin.setConstant(std::numeric_limits<double>::max());
+  boxMax.setConstant(-std::numeric_limits<double>::max());
+
+  const bool noSelection = isSelectionEmpty();
+
+  for (uint32_t i = 0; i < atomCount(); i++) {
+    if (noSelection || m_selectedAtoms[i]) {
+
+      const Vector3 boxMinBuffer = atom(i).position3d().array() - radius;
+      const Vector3 boxMaxBuffer = atom(i).position3d().array() + radius;
+
+      boxMin.x() = std::min(boxMinBuffer.x(), boxMin.x());
+      boxMin.y() = std::min(boxMinBuffer.y(), boxMin.y());
+      boxMin.z() = std::min(boxMinBuffer.z(), boxMin.z());
+
+      boxMax.x() = std::max(boxMaxBuffer.x(), boxMax.x());
+      boxMax.y() = std::max(boxMaxBuffer.y(), boxMax.y());
+      boxMax.z() = std::max(boxMaxBuffer.z(), boxMax.z());
+    }
+  }
+}
+
+} // namespace Avogadro::Core
