@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "nameatomtyper.h"
@@ -19,8 +8,7 @@
 #include "atom.h"
 #include "elements.h"
 
-namespace Avogadro {
-namespace Core {
+namespace Avogadro::Core {
 
 NameAtomTyper::NameAtomTyper(const Molecule* mol) : AtomTyper<std::string>(mol)
 {
@@ -35,5 +23,4 @@ std::string NameAtomTyper::type(const Atom& atom)
   return std::string(Elements::name(atom.atomicNumber()));
 }
 
-} // namespace Core
 } // namespace Avogadro
