@@ -18,7 +18,8 @@ using namespace std;
 
 SecondaryStructureAssigner::SecondaryStructureAssigner(Molecule* mol)
   : m_molecule(mol)
-{}
+{
+}
 
 SecondaryStructureAssigner::~SecondaryStructureAssigner()
 {
@@ -60,7 +61,7 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
   }
 
   // Plug gaps in the helix
-  for (auto i = 1; i < residueCount - 1; ++i) {
+  for (size_t i = 1; i < residueCount - 1; ++i) {
     // check that before and after this residue are in the same chain
     if (m_molecule->residue(i).chainId() !=
           m_molecule->residue(i - 1).chainId() ||
@@ -78,13 +79,12 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
   }
 
   // Then assign the beta sheet - but only if a residue isn't assigned
-  const auto maybeBeta =
-    static_cast<const Residue::SecondaryStructure>(-3);
   for (auto hBond : m_hBonds) {
     if (hBond->distSquared < infinity) {
       if (m_molecule->residue(hBond->residue).secondaryStructure() ==
           Residue::SecondaryStructure::undefined)
-        m_molecule->residue(hBond->residue).setSecondaryStructure(maybeBeta);
+        m_molecule->residue(hBond->residue)
+          .setSecondaryStructure(Residue::SecondaryStructure::maybeBeta);
     }
   }
 
@@ -96,8 +96,10 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
       auto match = m_molecule->residue(hBond->residuePair);
 
       // if we're "maybe" beta see if the match is either beta or "maybe"
-      if (current.secondaryStructure() == maybeBeta &&
-          (match.secondaryStructure() == maybeBeta ||
+      if (current.secondaryStructure() ==
+            Residue::SecondaryStructure::maybeBeta &&
+          (match.secondaryStructure() ==
+             Residue::SecondaryStructure::maybeBeta ||
            match.secondaryStructure() ==
              Residue::SecondaryStructure::betaSheet)) {
         // we can be sure now
@@ -110,7 +112,7 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
   }
 
   // Plug gaps in the beta sheet
-  for (auto i = 1; i < residueCount - 1; ++i) {
+  for (size_t i = 1; i < residueCount - 1; ++i) {
     // check that before and after this residue are in the same chain
     if (m_molecule->residue(i).chainId() !=
           m_molecule->residue(i - 1).chainId() ||
@@ -128,7 +130,7 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
   }
 
   // remove singletons
-  for (auto i = 1; i < residueCount - 1; ++i) {
+  for (size_t i = 1; i < residueCount - 1; ++i) {
     // check that before and after this residue are in the same chain
     if (m_molecule->residue(i).chainId() !=
           m_molecule->residue(i - 1).chainId() ||
@@ -138,7 +140,7 @@ void SecondaryStructureAssigner::assign(Molecule* mol)
 
     auto current = m_molecule->residue(i);
     // clear maybeBeta assignments (e.g. short bits)
-    if (current.secondaryStructure() == maybeBeta)
+    if (current.secondaryStructure() == Residue::SecondaryStructure::maybeBeta)
       m_molecule->residue(i).setSecondaryStructure(
         Residue::SecondaryStructure::undefined);
 
@@ -173,9 +175,9 @@ void SecondaryStructureAssigner::assignBackboneHydrogenBonds()
 
   // Loop over the backbone atoms
   // we're just considering N and O (on a peptide)
-  unsigned int i = 0; // track the residue index
+  unsigned int idx = 0; // track the residue index
   for (const auto& residue : m_molecule->residues()) {
-    unsigned int residueId = i++;
+    unsigned int residueId = idx++;
     if (residue.isHeterogen())
       continue;
 
@@ -214,13 +216,13 @@ void SecondaryStructureAssigner::assignBackboneHydrogenBonds()
 
   // now loop through the sorted list (so we can exit quickly)
   int n = m_hBonds.size();
-  for (unsigned int i = 0; i < n; ++i) {
+  for (int i = 0; i < n; ++i) {
     auto recordI = m_hBonds[i];
-    const Residue &residueI = m_molecule->residue(recordI->residue);
+    const Residue& residueI = m_molecule->residue(recordI->residue);
 
-    for (unsigned int j = i + 1; j < n; ++j) {
+    for (int j = i + 1; j < n; ++j) {
       auto recordJ = m_hBonds[j];
-      const Residue &residueJ = m_molecule->residue(recordJ->residue);
+      const Residue& residueJ = m_molecule->residue(recordJ->residue);
 
       // skip if we're not on the same chain
       if (residueI.chainId() != residueJ.chainId())
@@ -265,4 +267,4 @@ void SecondaryStructureAssigner::assignBackboneHydrogenBonds()
   }   // end for(i)
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::Core
