@@ -6,6 +6,8 @@
 #ifndef AVOGADRO_CORE_VARIANT_H
 #define AVOGADRO_CORE_VARIANT_H
 
+#include "avogadrocoreexport.h"
+
 #include "avogadrocore.h"
 #include "matrix.h"
 
@@ -144,8 +146,8 @@ private:
   } m_value;
 };
 
-} // end Core namespace
-} // end Avogadro namespace
+} // namespace Core
+} // namespace Avogadro
 
 #include "variant-inline.h"
 
