@@ -12,6 +12,7 @@
 #include <avogadro/core/layermanager.h>
 #include <avogadro/core/molecule.h>
 #include <avogadro/core/residue.h>
+#include <avogadro/core/spacegroups.h>
 #include <avogadro/core/unitcell.h>
 #include <avogadro/core/utilities.h>
 
@@ -79,11 +80,32 @@ bool isBooleanArray(json& j)
   return false;
 }
 
+json eigenColToJson(const MatrixX& matrix, int column)
+{
+  json j;
+  j = json::array();
+  for (Index i = 0; i < matrix.rows(); ++i) {
+    j.push_back(matrix(i, column));
+  }
+  return j;
+}
+
 bool CjsonFormat::read(std::istream& file, Molecule& molecule)
 {
-  json jsonRoot = json::parse(file, nullptr, false);
+  return deserialize(file, molecule, true);
+}
+
+bool CjsonFormat::deserialize(std::istream& file, Molecule& molecule,
+                              bool isJson)
+{
+  json jsonRoot;
+  if (isJson)
+    jsonRoot = json::parse(file, nullptr, false);
+  else // msgpack
+    jsonRoot = json::from_msgpack(file);
+
   if (jsonRoot.is_discarded()) {
-    appendError("Error parsing JSON.");
+    appendError("Error reading CJSON file.");
     return false;
   }
 
@@ -119,11 +141,11 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   // This represents our minimal spec for a molecule - atoms that have an
   // atomic number.
   if (isNumericArray(atomicNumbers) && atomicNumbers.size() > 0) {
-    for (auto & atomicNumber : atomicNumbers)
+    for (auto& atomicNumber : atomicNumbers)
       molecule.addAtom(atomicNumber);
   } else {
-    appendError("Malformed array for in atoms.elements.number");
-    return false;
+    // we're done, actually - this is an empty file
+    return true;
   }
   Index atomCount = molecule.atomCount();
 
@@ -142,7 +164,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
   json labels = atoms["labels"];
   if (labels.is_array() && labels.size() == atomCount) {
     for (size_t i = 0; i < atomCount; ++i) {
-      molecule.atom(i).setLabel(labels[i]);
+      molecule.setAtomLabel(i, labels[i]);
     }
   }
 
@@ -202,21 +224,6 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
-  // Partial charges are optional, but if present should be loaded.
-  json partialCharges = atoms["partialCharges"];
-  if (partialCharges.is_object()) {
-    // keys are types, values are arrays of charges
-    for (auto& kv : partialCharges.items()) {
-      MatrixX charges(atomCount, 1);
-      if (isNumericArray(kv.value()) && kv.value().size() == atomCount) {
-        for (size_t i = 0; i < kv.value().size(); ++i) {
-          charges(i, 0) = kv.value()[i];
-        }
-        molecule.setPartialCharges(kv.key(), charges);
-      }
-    }
-  }
-
   // Bonds are optional, but if present should be loaded.
   json bonds = jsonRoot["bonds"];
   if (bonds.is_object() && isNumericArray(bonds["connections"]["index"])) {
@@ -232,6 +239,14 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
         molecule.bond(i).setOrder(static_cast<int>(order[i]));
       }
     }
+
+    // are there bond labels?
+    json bondLabels = bonds["labels"];
+    if (bondLabels.is_array() && bondLabels.size() == molecule.bondCount()) {
+      for (unsigned int i = 0; i < molecule.bondCount(); ++i) {
+        molecule.setBondLabel(i, bondLabels[i]);
+      }
+    }
   }
 
   // residues are optional, but should be loaded
@@ -302,6 +317,17 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
     if (unitCellObject != nullptr)
       molecule.setUnitCell(unitCellObject);
+
+    // check for Hall number if present
+    if (unitCell["hallNumber"].is_number()) {
+      auto hallNumber = static_cast<int>(unitCell["hallNumber"]);
+      if (hallNumber > 0 && hallNumber < 531)
+        molecule.setHallNumber(hallNumber);
+    } else if (unitCell["spaceGroup"].is_string()) {
+      auto hallNumber = Core::SpaceGroups::hallNumber(unitCell["spaceGroup"]);
+      if (hallNumber != 0)
+        molecule.setHallNumber(hallNumber);
+    }
   }
 
   json fractional = atoms["coords"]["3dFractional"];
@@ -367,42 +393,44 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
       json occupations = orbitals["occupations"];
       if (isNumericArray(occupations)) {
         std::vector<unsigned char> occs;
-        for (auto & occupation : occupations)
+        for (auto& occupation : occupations)
           occs.push_back(static_cast<unsigned char>(occupation));
         basis->setMolecularOrbitalOccupancy(occupations);
       }
       json energies = orbitals["energies"];
       if (isNumericArray(energies)) {
         std::vector<double> energyArray;
-        for (auto & energie : energies)
+        for (auto& energie : energies)
           energyArray.push_back(static_cast<double>(energie));
         basis->setMolecularOrbitalEnergy(energyArray);
       }
       json numbers = orbitals["numbers"];
       if (isNumericArray(numbers)) {
         std::vector<unsigned int> numArray;
-        for (auto & number : numbers)
+        for (auto& number : numbers)
           numArray.push_back(static_cast<unsigned int>(number));
         basis->setMolecularOrbitalNumber(numArray);
       }
       json moCoefficients = orbitals["moCoefficients"];
       json moCoefficientsA = orbitals["alphaCoefficients"];
       json moCoefficientsB = orbitals["betaCoefficients"];
+      bool openShell = false;
       if (isNumericArray(moCoefficients)) {
         std::vector<double> coeffs;
-        for (auto & moCoefficient : moCoefficients)
+        for (auto& moCoefficient : moCoefficients)
           coeffs.push_back(static_cast<double>(moCoefficient));
         basis->setMolecularOrbitals(coeffs);
       } else if (isNumericArray(moCoefficientsA) &&
                  isNumericArray(moCoefficientsB)) {
         std::vector<double> coeffsA;
-        for (auto & i : moCoefficientsA)
+        for (auto& i : moCoefficientsA)
           coeffsA.push_back(static_cast<double>(i));
         std::vector<double> coeffsB;
-        for (auto & i : moCoefficientsB)
+        for (auto& i : moCoefficientsB)
           coeffsB.push_back(static_cast<double>(i));
         basis->setMolecularOrbitals(coeffsA, BasisSet::Alpha);
         basis->setMolecularOrbitals(coeffsB, BasisSet::Beta);
+        openShell = true;
       } else {
         std::cout << "No orbital cofficients found!" << std::endl;
       }
@@ -416,24 +444,57 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
           moCoefficientsB = orbSets[idx]["betaCoefficients"];
           if (isNumericArray(moCoefficients)) {
             std::vector<double> coeffs;
-            for (auto & moCoefficient : moCoefficients)
+            for (auto& moCoefficient : moCoefficients)
               coeffs.push_back(static_cast<double>(moCoefficient));
             basis->setMolecularOrbitals(coeffs, BasisSet::Paired, idx);
           } else if (isNumericArray(moCoefficientsA) &&
                      isNumericArray(moCoefficientsB)) {
             std::vector<double> coeffsA;
-            for (auto & i : moCoefficientsA)
+            for (auto& i : moCoefficientsA)
               coeffsA.push_back(static_cast<double>(i));
             std::vector<double> coeffsB;
-            for (auto & i : moCoefficientsB)
+            for (auto& i : moCoefficientsB)
               coeffsB.push_back(static_cast<double>(i));
             basis->setMolecularOrbitals(coeffsA, BasisSet::Alpha, idx);
             basis->setMolecularOrbitals(coeffsB, BasisSet::Beta, idx);
+            openShell = true;
           }
         }
         // Set the first step as active.
         basis->setActiveSetStep(0);
       }
+      if (openShell) {
+        // look for alpha and beta orbital energies
+        json energiesA = orbitals["alphaEnergies"];
+        json energiesB = orbitals["betaEnergies"];
+        // check if they are numeric arrays
+        if (isNumericArray(energiesA) && isNumericArray(energiesB)) {
+          std::vector<double> moEnergiesA;
+          for (auto& i : energiesA)
+            moEnergiesA.push_back(static_cast<double>(i));
+          std::vector<double> moEnergiesB;
+          for (auto& i : energiesB)
+            moEnergiesB.push_back(static_cast<double>(i));
+          basis->setMolecularOrbitalEnergy(moEnergiesA, BasisSet::Alpha);
+          basis->setMolecularOrbitalEnergy(moEnergiesB, BasisSet::Beta);
+
+          // look for alpha and beta orbital occupations
+          json occupationsA = orbitals["alphaOccupations"];
+          json occupationsB = orbitals["betaOccupations"];
+          // check if they are numeric arrays
+          if (isNumericArray(occupationsA) && isNumericArray(occupationsB)) {
+            std::vector<unsigned char> moOccupationsA;
+            for (auto& i : occupationsA)
+              moOccupationsA.push_back(static_cast<unsigned char>(i));
+            std::vector<unsigned char> moOccupationsB;
+            for (auto& i : occupationsB)
+              moOccupationsB.push_back(static_cast<unsigned char>(i));
+            basis->setMolecularOrbitalOccupancy(moOccupationsA,
+                                                BasisSet::Alpha);
+            basis->setMolecularOrbitalOccupancy(moOccupationsB, BasisSet::Beta);
+          }
+        }
+      }
     }
     molecule.setBasisSet(basis);
   }
@@ -444,7 +505,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     json frequencies = vibrations["frequencies"];
     if (isNumericArray(frequencies)) {
       Array<double> freqs;
-      for (auto & frequencie : frequencies) {
+      for (auto& frequencie : frequencies) {
         freqs.push_back(static_cast<double>(frequencie));
       }
       molecule.setVibrationFrequencies(freqs);
@@ -452,7 +513,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     json intensities = vibrations["intensities"];
     if (isNumericArray(intensities)) {
       Array<double> intens;
-      for (auto & intensitie : intensities) {
+      for (auto& intensitie : intensities) {
         intens.push_back(static_cast<double>(intensitie));
       }
       molecule.setVibrationIRIntensities(intens);
@@ -460,7 +521,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     json raman = vibrations["ramanIntensities"];
     if (isNumericArray(raman)) {
       Array<double> intens;
-      for (auto & i : raman) {
+      for (auto& i : raman) {
         intens.push_back(static_cast<double>(i));
       }
       molecule.setVibrationRamanIntensities(intens);
@@ -473,7 +534,7 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
           Array<Vector3> mode;
           mode.resize(arr.size() / 3);
           double* ptr = &mode[0][0];
-          for (auto & j : arr) {
+          for (auto& j : arr) {
             *(ptr++) = static_cast<double>(j);
           }
           disps.push_back(mode);
@@ -483,6 +544,141 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
     }
   }
 
+  // check for spectra data
+  json spectra = jsonRoot["spectra"];
+  if (spectra.is_object()) {
+    // electronic
+    json electronic = spectra["electronic"];
+    if (electronic.is_object()) {
+      // check to see "energies" and "intensities"
+      json energies = electronic["energies"];
+      json intensities = electronic["intensities"];
+      // make sure they are both numeric arrays
+      if (isNumericArray(energies) && isNumericArray(intensities)) {
+        // make sure they are the same size
+        if (energies.size() == intensities.size()) {
+          // create the matrix
+          MatrixX electronicData(energies.size(), 2);
+          // copy the data
+          for (std::size_t i = 0; i < energies.size(); ++i) {
+            electronicData(i, 0) = energies[i];
+            electronicData(i, 1) = intensities[i];
+          }
+          // set the data
+          molecule.setSpectra("Electronic", electronicData);
+        }
+      }
+      // check if there's CD data for "rotation"
+      json rotation = electronic["rotation"];
+      if (isNumericArray(rotation) && rotation.size() == energies.size()) {
+        MatrixX rotationData(rotation.size(), 2);
+        for (std::size_t i = 0; i < rotation.size(); ++i) {
+          rotationData(i, 0) = energies[i];
+          rotationData(i, 1) = rotation[i];
+        }
+        molecule.setSpectra("CircularDichroism", rotationData);
+      }
+    }
+
+    // nmr
+    json nmr = spectra["nmr"];
+    if (nmr.is_object()) {
+      // chemical shifts
+      json chemicalShifts = nmr["shifts"];
+      if (isNumericArray(chemicalShifts)) {
+        MatrixX chemicalShiftData(chemicalShifts.size(), 2);
+        for (std::size_t i = 0; i < chemicalShifts.size(); ++i) {
+          chemicalShiftData(i, 0) = static_cast<double>(chemicalShifts[i]);
+          chemicalShiftData(i, 1) = 1.0;
+        }
+        molecule.setSpectra("NMR", chemicalShiftData);
+      }
+    }
+  }
+
+  // properties
+  if (jsonRoot.find("properties") != jsonRoot.end()) {
+    json properties = jsonRoot["properties"];
+    if (properties.is_object()) {
+      if (properties.find("totalCharge") != properties.end()) {
+        molecule.setData("totalCharge",
+                         static_cast<int>(properties["totalCharge"]));
+      }
+      if (properties.find("totalSpinMultiplicity") != properties.end()) {
+        molecule.setData("totalSpinMultiplicity",
+                         static_cast<int>(properties["totalSpinMultiplicity"]));
+      }
+      // iterate through everything else
+      for (auto& element : properties.items()) {
+        if (element.key() == "totalCharge" ||
+            element.key() == "totalSpinMultiplicity") {
+          continue;
+        }
+        if (element.value().type() == json::value_t::array) {
+          // check if it is a numeric array to go into Eigen::MatrixXd
+          json j = element.value(); // convenience
+          std::size_t rows = j.size();
+          MatrixX matrix;
+          matrix.resize(rows, 1); // default to 1 columns
+          bool isNumeric = true;
+
+          for (std::size_t row = 0; row < j.size(); ++row) {
+            const auto& jrow = j.at(row);
+            // check to see if we have a simple vector or a matrix
+            if (jrow.type() == json::value_t::array) {
+              matrix.conservativeResize(rows, jrow.size());
+              for (std::size_t col = 0; col < jrow.size(); ++col) {
+                const auto& value = jrow.at(col);
+                if (value.type() == json::value_t::number_float ||
+                    value.type() == json::value_t::number_integer ||
+                    value.type() == json::value_t::number_unsigned)
+                  matrix(row, col) = value.get<double>();
+                else {
+                  isNumeric = false;
+                  break;
+                }
+              }
+            } else if (jrow.type() == json::value_t::number_float ||
+                       jrow.type() == json::value_t::number_integer ||
+                       jrow.type() == json::value_t::number_unsigned) {
+              // just a row vector
+              matrix(row, 0) = jrow.get<double>();
+            } else {
+              isNumeric = false;
+              break;
+            }
+          }
+          if (isNumeric)
+            molecule.setData(element.key(), matrix);
+          // TODO: add support for non-numeric arrays
+          // std::cout << " property: " << element.key() << " = " << matrix
+          //           << " size " << matrix.rows() << 'x' << matrix.cols()
+          //          << std::endl;
+        } else {
+          molecule.setData(element.key(), element.value());
+          // std::cout << " property: " << element.key() << " = "
+          //          << element.value() << " type "
+          //          << element.value().type_name() << std::endl;
+        }
+      }
+    }
+  }
+
+  // Partial charges are optional, but if present should be loaded.
+  json partialCharges = atoms["partialCharges"];
+  if (partialCharges.is_object()) {
+    // keys are types, values are arrays of charges
+    for (auto& kv : partialCharges.items()) {
+      MatrixX charges(atomCount, 1);
+      if (isNumericArray(kv.value()) && kv.value().size() == atomCount) {
+        for (size_t i = 0; i < kv.value().size(); ++i) {
+          charges(i, 0) = kv.value()[i];
+        }
+        molecule.setPartialCharges(kv.key(), charges);
+      }
+    }
+  }
+
   if (jsonRoot.find("layer") != jsonRoot.end()) {
     auto names = LayerManager::getMoleculeInfo(&molecule);
     json visible = jsonRoot["layer"]["visible"];
@@ -519,6 +715,12 @@ bool CjsonFormat::read(std::istream& file, Molecule& molecule)
 }
 
 bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
+{
+  return serialize(file, molecule, true);
+}
+
+bool CjsonFormat::serialize(std::ostream& file, const Molecule& molecule,
+                            bool isJson)
 {
   json opts;
   if (!options().empty())
@@ -537,6 +739,42 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
       root["inchi"] = molecule.data("inchi").toString().c_str();
   }
 
+  json properties;
+  // these methods assume neutral singlet if not set
+  // or approximate from formal charges and # of electrons
+  properties["totalCharge"] = molecule.totalCharge();
+  properties["totalSpinMultiplicity"] = molecule.totalSpinMultiplicity();
+  // loop through all other properties
+  const auto map = molecule.dataMap();
+  for (const auto& element : map) {
+    if (element.first == "name" || element.first == "inchi")
+      continue;
+
+    if (element.second.type() == Variant::String)
+      properties[element.first] = element.second.toString().c_str();
+    else if (element.second.type() == Variant::Double)
+      properties[element.first] = element.second.toDouble();
+    else if (element.second.type() == Variant::Float)
+      properties[element.first] = element.second.toFloat();
+    else if (element.second.type() == Variant::Int)
+      properties[element.first] = element.second.toInt();
+    else if (element.second.type() == Variant::Bool)
+      properties[element.first] = element.second.toBool();
+    else if (element.second.type() == Variant::Matrix) {
+      MatrixX m = element.second.toMatrix();
+      json matrix;
+      for (int i = 0; i < m.rows(); ++i) {
+        json row;
+        for (int j = 0; j < m.cols(); ++j) {
+          row.push_back(m(i, j));
+        }
+        matrix.push_back(row);
+      }
+      properties[element.first] = matrix;
+    }
+  }
+  root["properties"] = properties;
+
   if (molecule.unitCell()) {
     json unitCell;
     unitCell["a"] = molecule.unitCell()->a();
@@ -560,9 +798,37 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     vectors.push_back(molecule.unitCell()->cVector().z());
     unitCell["cellVectors"] = vectors;
 
+    // write the Hall number and space group
+    unitCell["hallNumber"] = molecule.hallNumber();
+    unitCell["spaceGroup"] =
+      Core::SpaceGroups::international(molecule.hallNumber());
+
     root["unitCell"] = unitCell;
   }
 
+  // check for spectra data
+  if (molecule.spectraTypes().size() != 0) {
+    json spectra, electronic, nmr;
+    bool hasElectronic = false;
+    for (const auto& type : molecule.spectraTypes()) {
+      if (type == "Electronic") {
+        hasElectronic = true;
+        electronic["energies"] = eigenColToJson(molecule.spectra(type), 0);
+        electronic["intensities"] = eigenColToJson(molecule.spectra(type), 1);
+      } else if (type == "CircularDichroism") {
+        electronic["rotation"] = eigenColToJson(molecule.spectra(type), 1);
+      } else if (type == "NMR") {
+        json data;
+        data["shifts"] = eigenColToJson(molecule.spectra(type), 0);
+        spectra["nmr"] = data;
+      }
+    }
+    if (hasElectronic) {
+      spectra["electronic"] = electronic;
+    }
+    root["spectra"] = spectra;
+  }
+
   // Create a basis set/MO matrix we can round trip.
   if (molecule.basisSet() &&
       dynamic_cast<const GaussianSet*>(molecule.basisSet())) {
@@ -593,7 +859,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     }
     basis["shellTypes"] = shellTypes;
 
-    // This bit is slightly tricky, map from our index to primitives per shell.
+    // This bit is slightly tricky, map from our index to primitives per
+    // shell.
     if (gaussian->gtoIndices().size() && gaussian->atomIndices().size()) {
       auto gtoIndices = gaussian->gtoIndices();
       auto gtoA = gaussian->gtoA();
@@ -605,7 +872,7 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
 
       auto atomIndices = gaussian->atomIndices();
       json shellToAtomMap;
-      for (unsigned int & atomIndice : atomIndices)
+      for (unsigned int& atomIndice : atomIndices)
         shellToAtomMap.push_back(atomIndice);
       basis["shellToAtomMap"] = shellToAtomMap;
 
@@ -623,8 +890,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
       root["basisSet"] = basis;
     }
 
-    // Now get the MO matrix, potentially other things. Need to get a handle on
-    // when we have just one (paired), or two (alpha and beta) to write.
+    // Now get the MO matrix, potentially other things. Need to get a handle
+    // on when we have just one (paired), or two (alpha and beta) to write.
     auto moMatrix = gaussian->moMatrix();
     auto betaMatrix = gaussian->moMatrix(BasisSet::Beta);
     json moCoefficients;
@@ -648,22 +915,41 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     auto energies = gaussian->moEnergy();
     if (energies.size() > 0) {
       json energyData;
-      for (double & energie : energies) {
+      for (double& energie : energies) {
         energyData.push_back(energie);
       }
-      root["orbitals"]["energies"] = energyData;
+
+      auto betaEnergies = gaussian->moEnergy(BasisSet::Beta);
+      if (betaEnergies.size() > 0) {
+        json betaEnergyData;
+        for (double& energie : betaEnergies) {
+          betaEnergyData.push_back(energie);
+        }
+        root["orbitals"]["alphaEnergies"] = energyData;
+        root["orbitals"]["betaEnergies"] = betaEnergyData;
+      } else
+        root["orbitals"]["energies"] = energyData;
     }
     auto occ = gaussian->moOccupancy();
     if (occ.size() > 0) {
       json occData;
-      for (unsigned char & it : occ)
+      for (unsigned char& it : occ)
         occData.push_back(static_cast<int>(it));
-      root["orbitals"]["occupations"] = occData;
+
+      auto betaOcc = gaussian->moOccupancy(BasisSet::Beta);
+      if (betaOcc.size() > 0) {
+        json betaOccData;
+        for (unsigned char& it : betaOcc)
+          betaOccData.push_back(static_cast<int>(it));
+        root["orbitals"]["alphaOccupations"] = occData;
+        root["orbitals"]["betaOccupations"] = betaOccData;
+      } else
+        root["orbitals"]["occupations"] = occData;
     }
     auto num = gaussian->moNumber();
     if (num.size() > 0) {
       json numData;
-      for (unsigned int & it : num)
+      for (unsigned int& it : num)
         numData.push_back(it);
       root["orbitals"]["numbers"] = numData;
     }
@@ -722,11 +1008,25 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     if (hasCustomColors)
       root["atoms"]["colors"] = colors;
 
+    // check for partial charges
+    auto partialCharges = molecule.partialChargeTypes();
+    if (!partialCharges.empty()) {
+      // add them to the atoms object
+      for (const auto& type : partialCharges) {
+        MatrixX chargesMatrix = molecule.partialCharges(type);
+        json charges;
+        for (Index i = 0; i < molecule.atomCount(); ++i) {
+          charges.push_back(chargesMatrix(i, 0));
+        }
+        root["atoms"]["partialCharges"][type] = charges;
+      }
+    }
+
     // 3d positions:
     if (molecule.atomPositions3d().size() == molecule.atomCount()) {
       // everything gets real-space Cartesians
       json coords3d;
-      for (const auto & it : molecule.atomPositions3d()) {
+      for (const auto& it : molecule.atomPositions3d()) {
         coords3d.push_back(it.x());
         coords3d.push_back(it.y());
         coords3d.push_back(it.z());
@@ -739,7 +1039,7 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
         Array<Vector3> fcoords;
         CrystalTools::fractionalCoordinates(
           *molecule.unitCell(), molecule.atomPositions3d(), fcoords);
-        for (auto & fcoord : fcoords) {
+        for (auto& fcoord : fcoords) {
           coordsFractional.push_back(fcoord.x());
           coordsFractional.push_back(fcoord.y());
           coordsFractional.push_back(fcoord.z());
@@ -751,7 +1051,7 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     // 2d positions:
     if (molecule.atomPositions2d().size() == molecule.atomCount()) {
       json coords2d;
-      for (const auto & it : molecule.atomPositions2d()) {
+      for (const auto& it : molecule.atomPositions2d()) {
         coords2d.push_back(it.x());
         coords2d.push_back(it.y());
       }
@@ -759,12 +1059,15 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     }
   }
 
-  // labels
-  json labels;
-  for (size_t i = 0; i < molecule.atomCount(); ++i) {
-    labels.push_back(molecule.label(i));
+  // check for atom labels
+  Array atomLabels = molecule.atomLabels();
+  if (atomLabels.size() == molecule.atomCount()) {
+    json labels;
+    for (Index i = 0; i < molecule.atomCount(); ++i) {
+      labels.push_back(atomLabels[i]);
+    }
+    root["atoms"]["labels"] = labels;
   }
-  root["atoms"]["labels"] = labels;
 
   // formal charges
   json formalCharges;
@@ -794,6 +1097,16 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     }
     root["bonds"]["connections"]["index"] = connections;
     root["bonds"]["order"] = order;
+
+    // check if there are bond labels
+    Array bondLabels = molecule.bondLabels();
+    if (bondLabels.size() == molecule.bondCount()) {
+      json labels;
+      for (Index i = 0; i < molecule.bondCount(); ++i) {
+        labels.push_back(bondLabels[i]);
+      }
+      root["bonds"]["labels"] = labels;
+    }
   }
 
   // Create and populate any residue arrays
@@ -839,7 +1152,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
       modes.push_back(static_cast<unsigned int>(i) + 1);
       freqs.push_back(molecule.vibrationFrequencies()[i]);
       inten.push_back(molecule.vibrationIRIntensities()[i]);
-      raman.push_back(molecule.vibrationRamanIntensities()[i]);
+      if (molecule.vibrationRamanIntensities().size() > i)
+        raman.push_back(molecule.vibrationRamanIntensities()[i]);
       Core::Array<Vector3> atomDisplacements = molecule.vibrationLx(i);
       json eigenVector;
       for (auto pos : atomDisplacements) {
@@ -852,7 +1166,8 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     root["vibrations"]["modes"] = modes;
     root["vibrations"]["frequencies"] = freqs;
     root["vibrations"]["intensities"] = inten;
-    root["vibrations"]["ramanIntensities"] = raman;
+    if (molecule.vibrationRamanIntensities().size() > 0)
+      root["vibrations"]["ramanIntensities"] = raman;
     root["vibrations"]["eigenVectors"] = eigenVectors;
   }
 
@@ -883,8 +1198,11 @@ bool CjsonFormat::write(std::ostream& file, const Molecule& molecule)
     root["layer"]["settings"][settings.first] = setting;
   }
 
-  // Write out the file, use a two space indent to "pretty print".
-  file << std::setw(2) << root;
+  if (isJson)
+    file << std::setw(2) << root;
+  else { // write msgpack
+    json::to_msgpack(root, file);
+  }
 
   return true;
 }
@@ -903,4 +1221,4 @@ vector<std::string> CjsonFormat::mimeTypes() const
   return mime;
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::Io
