@@ -53,6 +53,10 @@ bool LammpsTrajectoryFormat::read(std::istream& inStream, Core::Molecule& mol)
          tilt_xy = 0, tilt_xz = 0, tilt_yz = 0, scale_x = 0., scale_y = 0.,
          scale_z = 0.;
 
+  // This can likely be removed as it is clearly not used anywhere, suppress for
+  // now.
+  AVO_UNUSED(id_idx);
+
   string buffer;
   getline(inStream, buffer); // Finish the first line
   buffer = trimmed(buffer);
@@ -154,10 +158,11 @@ bool LammpsTrajectoryFormat::read(std::istream& inStream, Core::Molecule& mol)
     } else if (labels[i] == "zs" || labels[i] == "zsu") {
       z_idx = i;
       scale_z = 1.;
-    } else if (labels[i] == "type")
+    } else if (labels[i] == "type") {
       type_idx = i;
-    else if (labels[i] == "id")
+    } else if (labels[i] == "id") {
       id_idx = i;
+    }
   }
 
   // Parse atoms
@@ -202,7 +207,7 @@ bool LammpsTrajectoryFormat::read(std::istream& inStream, Core::Molecule& mol)
   // Set the custom element map if needed:
   if (!atomTypes.empty()) {
     Molecule::CustomElementMap elementMap;
-    for (const auto & atomType : atomTypes) {
+    for (const auto& atomType : atomTypes) {
       elementMap.insert(std::make_pair(atomType.second, atomType.first));
     }
     mol.setCustomElementMap(elementMap);
@@ -339,10 +344,11 @@ bool LammpsTrajectoryFormat::read(std::istream& inStream, Core::Molecule& mol)
       } else if (labels[i] == "zs" || labels[i] == "zsu") {
         z_idx = i;
         scale_z = 1.;
-      } else if (labels[i] == "type")
+      } else if (labels[i] == "type") {
         type_idx = i;
-      else if (labels[i] == "id")
+      } else if (labels[i] == "id") {
         id_idx = i;
+      }
     }
 
     Array<Vector3> positions;
@@ -379,8 +385,7 @@ bool LammpsTrajectoryFormat::read(std::istream& inStream, Core::Molecule& mol)
   return true;
 }
 
-bool LammpsTrajectoryFormat::write(std::ostream& outStream,
-                                   const Core::Molecule& mol)
+bool LammpsTrajectoryFormat::write(std::ostream&, const Core::Molecule&)
 {
   return false;
 }
@@ -403,7 +408,7 @@ LammpsDataFormat::LammpsDataFormat() {}
 
 LammpsDataFormat::~LammpsDataFormat() {}
 
-bool LammpsDataFormat::read(std::istream& inStream, Core::Molecule& mol)
+bool LammpsDataFormat::read(std::istream&, Core::Molecule&)
 {
   return false;
 }
@@ -421,6 +426,7 @@ bool LammpsDataFormat::write(std::ostream& outStream, const Core::Molecule& mol)
 
   std::ostringstream massStream, atomStream, bondStream;
   double xmin, xmax, ymin, ymax, zmin, zmax;
+  xmin = xmax = ymin = ymax = zmin = zmax = 0.0;
 
   size_t numAtoms = mol2.atomCount();
   outStream << to_string(numAtoms) << " atoms\n";
@@ -432,7 +438,7 @@ bool LammpsDataFormat::write(std::ostream& outStream, const Core::Molecule& mol)
   size_t idx = 1;
   Array<unsigned char> atomicNumbers = mol2.atomicNumbers();
   std::map<unsigned char, size_t> composition;
-  for (unsigned char & atomicNumber : atomicNumbers) {
+  for (unsigned char& atomicNumber : atomicNumbers) {
     if (composition.find(atomicNumber) == composition.end()) {
       composition[atomicNumber] = idx++;
     }
@@ -478,9 +484,9 @@ bool LammpsDataFormat::write(std::ostream& outStream, const Core::Molecule& mol)
       const unsigned int lineSize = 256;
       char atomline[lineSize];
       snprintf(atomline, lineSize - 1, "%-*d %d %10f %10f %10f\n",
-              static_cast<int>(log(numAtoms)) + 1, static_cast<int>(i + 1),
-              static_cast<int>(composition[atomicNumbers[i]]), coords.x(),
-              coords.y(), coords.z());
+               static_cast<int>(log(numAtoms)) + 1, static_cast<int>(i + 1),
+               static_cast<int>(composition[atomicNumbers[i]]), coords.x(),
+               coords.y(), coords.z());
       atomStream << atomline;
     }
 
@@ -500,32 +506,32 @@ bool LammpsDataFormat::write(std::ostream& outStream, const Core::Molecule& mol)
                                       b.atom2().atomicNumber())) !=
           bondIds.end()) {
         snprintf(bondline, lineSize - 1, "%-*d %7d %7d %7d\n",
-                static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
-                bondIds[std::make_pair(b.atom1().atomicNumber(),
-                                       b.atom2().atomicNumber())],
-                static_cast<int>(b.atom1().index() + 1),
-                static_cast<int>(b.atom2().index() + 1));
+                 static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
+                 bondIds[std::make_pair(b.atom1().atomicNumber(),
+                                        b.atom2().atomicNumber())],
+                 static_cast<int>(b.atom1().index() + 1),
+                 static_cast<int>(b.atom2().index() + 1));
         bondStream << bondline;
       } else if (bondIds.find(std::make_pair(b.atom2().atomicNumber(),
                                              b.atom1().atomicNumber())) !=
                  bondIds.end()) {
         snprintf(bondline, lineSize - 1, "%-*d %7d %7d %7d\n",
-                static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
-                bondIds[std::make_pair(b.atom1().atomicNumber(),
-                                       b.atom2().atomicNumber())],
-                static_cast<int>(b.atom2().index() + 1),
-                static_cast<int>(b.atom1().index() + 1));
+                 static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
+                 bondIds[std::make_pair(b.atom1().atomicNumber(),
+                                        b.atom2().atomicNumber())],
+                 static_cast<int>(b.atom2().index() + 1),
+                 static_cast<int>(b.atom1().index() + 1));
         bondStream << bondline;
       } else {
         bondIds.insert(std::make_pair(
           std::make_pair(b.atom1().atomicNumber(), b.atom2().atomicNumber()),
           bondItr++));
         snprintf(bondline, lineSize - 1, "%-*d %7d %7d %7d\n",
-                static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
-                bondIds[std::make_pair(b.atom1().atomicNumber(),
-                                       b.atom2().atomicNumber())],
-                static_cast<int>(b.atom1().index() + 1),
-                static_cast<int>(b.atom2().index() + 1));
+                 static_cast<int>(log(numAtoms) + 1), static_cast<int>(i + 1),
+                 bondIds[std::make_pair(b.atom1().atomicNumber(),
+                                        b.atom2().atomicNumber())],
+                 static_cast<int>(b.atom1().index() + 1),
+                 static_cast<int>(b.atom2().index() + 1));
         bondStream << bondline;
       }
     }
@@ -537,17 +543,17 @@ bool LammpsDataFormat::write(std::ostream& outStream, const Core::Molecule& mol)
   if (unitcell) {
     const Matrix3& mat = unitcell->cellMatrix().transpose();
     snprintf(simBoxBlock, lineSize - 1,
-            "%10f %10f xlo xhi\n%10f %10f ylo yhi\n%10f %10f zlo zhi\n%10f "
-            "%10f %10f xy xz yz",
-            0.0, mat(0, 0), 0.0, mat(1, 1), 0.0, mat(2, 2), mat(1, 0),
-            mat(2, 0), mat(2, 1));
+             "%10f %10f xlo xhi\n%10f %10f ylo yhi\n%10f %10f zlo zhi\n%10f "
+             "%10f %10f xy xz yz",
+             0.0, mat(0, 0), 0.0, mat(1, 1), 0.0, mat(2, 2), mat(1, 0),
+             mat(2, 0), mat(2, 1));
     outStream << simBoxBlock;
   } else {
     snprintf(simBoxBlock, lineSize - 1,
-            "%10f %10f xlo xhi\n%10f %10f ylo yhi\n%10f %10f zlo zhi\n%10f "
-            "%10f %10f xy xz yz",
-            xmin - 0.5, xmax - 0.5, ymin - 0.5, ymax - 0.5, zmin - 0.5,
-            zmax - 0.5, 0.0, 0.0, 0.0);
+             "%10f %10f xlo xhi\n%10f %10f ylo yhi\n%10f %10f zlo zhi\n%10f "
+             "%10f %10f xy xz yz",
+             xmin - 0.5, xmax - 0.5, ymin - 0.5, ymax - 0.5, zmin - 0.5,
+             zmax - 0.5, 0.0, 0.0, 0.0);
     outStream << simBoxBlock;
   }
   outStream << std::endl << std::endl << std::endl;
@@ -572,4 +578,4 @@ std::vector<std::string> LammpsDataFormat::mimeTypes() const
   return mime;
 }
 
-} // end Avogadro namespace
+} // namespace Avogadro::Io
