@@ -58,6 +58,8 @@ bool TurbomoleFormat::read(std::istream& inStream, Core::Molecule& mol)
 
   // possible lattice constants
   Real a, b, c, alpha, beta, gamma;
+  a = b = c = 100.0;
+  alpha = beta = gamma = 90.0;
   // defaults if periodicity is not 3
   Vector3 v1(100.0, 0.0, 0.0);
   Vector3 v2(0.0, 100.0, 0.0);
@@ -176,8 +178,10 @@ bool TurbomoleFormat::read(std::istream& inStream, Core::Molecule& mol)
   }
 
   // This format has no connectivity information, so perceive basics at least.
-  if (opts.value("perceiveBonds", true))
+  if (opts.value("perceiveBonds", true)) {
     mol.perceiveBondsSimple();
+    mol.perceiveBondOrders();
+  }
 
   return true;
 }
