@@ -11,7 +11,7 @@
 #include <QtCore/QJsonArray>
 #include <QtCore/QJsonObject>
 #include <QtCore/QObject>
-#include <QtCore/QRegExp>
+#include <QRegExp>
 #include <QtCore/QHash>
 
 namespace Avogadro {
