@@ -15,6 +15,8 @@
 #include <QtCore/QMap>
 #include <QtCore/QStringList>
 
+#include <QRegExp>
+
 class QJsonDocument;
 class QProcess;
 class QTextCharFormat;
@@ -191,7 +193,7 @@ namespace MoleQueue {
 }
 ~~~
  * This will result in a QCheckBox in the dynamically generated GUI, with
- * the inital check state shown in `default`.
+ * the initial check state shown in `default`.
  *
  * Special Parameters
  * ------------------
@@ -590,7 +592,7 @@ public slots:
 private:
   QtGui::PythonScript* m_interpreter;
 
-  void setDefaultPythonInterpretor();
+  void setDefaultPythonInterpreter();
   QByteArray execute(const QStringList& args,
                      const QByteArray& scriptStdin = QByteArray()) const;
   bool parseJson(const QByteArray& json, QJsonDocument& doc) const;
