@@ -5,27 +5,23 @@
 
 #include "filebrowsewidget.h"
 
+#include <QFileSystemModel>
 #include <QtWidgets/QCompleter>
 #include <QtWidgets/QFileDialog>
-#include <QtWidgets/QFileSystemModel>
 #include <QtWidgets/QHBoxLayout>
 #include <QtWidgets/QLineEdit>
 #include <QtWidgets/QPushButton>
 
-#include <QtCore/QFileInfo>
-#include <QtCore/QProcessEnvironment>
-#include <QtCore/QRegExp>
+#include <QFileInfo>
+#include <QProcessEnvironment>
+#include <QRegExp>
 
 namespace Avogadro::QtGui {
 
 FileBrowseWidget::FileBrowseWidget(QWidget* theParent)
-  : QWidget(theParent)
-  , m_mode()
-  , // use the setter to initialize filters.
-  m_valid(false)
-  , m_fileSystemModel(new QFileSystemModel(this))
-  , m_button(new QPushButton(tr("Browse")))
-  , m_edit(new QLineEdit)
+  : QWidget(theParent), m_mode(), // use the setter to initialize filters.
+    m_valid(false), m_fileSystemModel(new QFileSystemModel(this)),
+    m_button(new QPushButton(tr("Browse"))), m_edit(new QLineEdit)
 {
   auto* hbox = new QHBoxLayout;
   hbox->addWidget(m_edit);
@@ -152,6 +148,37 @@ void FileBrowseWidget::fileNameNoMatch()
   m_valid = false;
 }
 
+QStringList FileBrowseWidget::searchSystemPathForFiles(const QStringList& execs)
+{
+  QStringList result;
+  QProcessEnvironment env = QProcessEnvironment::systemEnvironment();
+  if (!env.contains(QStringLiteral("PATH")))
+    return result;
+
+  static QString pathSplitter =
+#ifdef Q_OS_WIN32
+    ";"
+#else  // WIN32
+    ":"
+#endif // WIN32
+    ;
+  QStringList paths =
+    env.value(QStringLiteral("PATH")).split(pathSplitter, Qt::SkipEmptyParts);
+
+  foreach (const QString& exec, execs) {
+    foreach (const QString& path, paths) {
+      QFileInfo info(path + "/" + exec);
+      if (!info.exists() || !info.isFile()) {
+        continue;
+      }
+      result << info.absoluteFilePath();
+      break;
+    }
+  }
+
+  return result;
+}
+
 QString FileBrowseWidget::searchSystemPathForFile(const QString& exec)
 {
   QString result;
@@ -159,15 +186,15 @@ QString FileBrowseWidget::searchSystemPathForFile(const QString& exec)
   if (!env.contains(QStringLiteral("PATH")))
     return result;
 
-  static QRegExp pathSplitter = QRegExp(
+  static QString pathSplitter =
 #ifdef Q_OS_WIN32
     ";"
 #else  // WIN32
     ":"
 #endif // WIN32
-  );
-  QStringList paths = env.value(QStringLiteral("PATH"))
-                        .split(pathSplitter, QString::SkipEmptyParts);
+    ;
+  QStringList paths =
+    env.value(QStringLiteral("PATH")).split(pathSplitter, Qt::SkipEmptyParts);
 
   foreach (const QString& path, paths) {
     QFileInfo info(path + "/" + exec);
@@ -201,4 +228,4 @@ FileBrowseWidget::Mode FileBrowseWidget::mode() const
   return m_mode;
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtGui
