@@ -21,6 +21,8 @@
 #include <QtCore/QJsonArray>
 #include <QtCore/QJsonDocument>
 
+#include <QtWidgets/QMessageBox>
+
 namespace Avogadro::QtGui {
 
 using QtGui::GenericHighlighter;
@@ -30,12 +32,14 @@ InterfaceScript::InterfaceScript(const QString& scriptFilePath_,
                                  QObject* parent_)
   : QObject(parent_), m_interpreter(new PythonScript(scriptFilePath_, this)),
     m_moleculeExtension(QStringLiteral("Unknown"))
-{}
+{
+}
 
 InterfaceScript::InterfaceScript(QObject* parent_)
   : QObject(parent_), m_interpreter(new PythonScript(this)),
     m_moleculeExtension(QStringLiteral("Unknown"))
-{}
+{
+}
 
 InterfaceScript::~InterfaceScript() {}
 
@@ -132,7 +136,7 @@ void InterfaceScript::setScriptFilePath(const QString& scriptFile)
 
 void InterfaceScript::reset()
 {
-  m_interpreter->setDefaultPythonInterpretor();
+  m_interpreter->setDefaultPythonInterpreter();
   m_interpreter->setScriptFilePath(QString());
   m_moleculeExtension = QLatin1String("Unknown");
   m_displayName = QString();
@@ -162,7 +166,8 @@ bool InterfaceScript::runCommand(const QJsonObject& options_,
   if (!insertMolecule(allOptions, *mol))
     return false;
 
-  connect(m_interpreter, &PythonScript::finished, this, &::Avogadro::QtGui::InterfaceScript::commandFinished);
+  connect(m_interpreter, &PythonScript::finished, this,
+          &::Avogadro::QtGui::InterfaceScript::commandFinished);
   m_interpreter->asyncExecute(QStringList() << QStringLiteral("--run-command"),
                               QJsonDocument(allOptions).toJson());
   return true;
@@ -230,8 +235,8 @@ bool InterfaceScript::processCommand(Core::Molecule* mol)
     if (m_moleculeExtension == "cjson") {
       // convert the "cjson" field to a string
       QJsonObject cjsonObj = obj["cjson"].toObject();
-      QJsonDocument doc(cjsonObj);
-      QString strCJSON(doc.toJson(QJsonDocument::Compact));
+      QJsonDocument doc2(cjsonObj);
+      QString strCJSON(doc2.toJson(QJsonDocument::Compact));
       if (!strCJSON.isEmpty()) {
         result = format->readString(strCJSON.toStdString(), newMol);
       }
@@ -244,15 +249,52 @@ bool InterfaceScript::processCommand(Core::Molecule* mol)
     // check if the script wants us to perceive bonds first
     if (obj["bond"].toBool()) {
       newMol.perceiveBondsSimple();
+      newMol.perceiveBondOrders();
     }
 
-    if (obj["append"].toBool()) { // just append some new bits
+    // how do we handle this result?
+    if (obj["readProperties"].toBool()) {
+      guiMol->readProperties(newMol);
+      guiMol->emitChanged(Molecule::Properties | Molecule::Added);
+    } else if (obj["append"].toBool()) {
       guiMol->undoMolecule()->appendMolecule(newMol, m_displayName);
     } else { // replace the whole molecule
       Molecule::MoleculeChanges changes = (Molecule::Atoms | Molecule::Bonds |
                                            Molecule::Added | Molecule::Removed);
       guiMol->undoMolecule()->modifyMolecule(newMol, changes, m_displayName);
     }
+
+    // select some atoms
+    if (obj.contains("selectedAtoms") && obj["selectedAtoms"].isArray()) {
+      QJsonArray selectedList = obj["selectedAtoms"].toArray();
+      for (int i = 0; i < selectedList.size(); ++i) {
+        if (selectedList[i].isDouble()) {
+          Index index = static_cast<Index>(selectedList[i].toDouble());
+          if (index >= 0 && index < guiMol->atomCount())
+            guiMol->undoMolecule()->setAtomSelected(index, true);
+        }
+      }
+      guiMol->emitChanged(Molecule::Atoms);
+    }
+
+    // check if there are messages for the user
+    if (obj.contains("message")) {
+      QString message;
+
+      if (obj["message"].isString())
+        message = obj["message"].toString();
+      else if (obj["message"].isArray()) {
+        QJsonArray messageList = obj["message"].toArray();
+        for (int i = 0; i < messageList.size(); ++i) {
+          if (messageList[i].isString())
+            message += messageList[i].toString() + "\n";
+        }
+      }
+      if (!message.isEmpty()) {
+        QMessageBox::information(qobject_cast<QWidget*>(parent()),
+                                 tr("%1 Message").arg(m_displayName), message);
+      }
+    }
   }
   return result;
 }
@@ -470,18 +512,28 @@ bool InterfaceScript::insertMolecule(QJsonObject& json,
   if (m_moleculeExtension == QLatin1String("None"))
     return true;
 
-  // insert the selected atoms
+  // Always insert the selected atoms
   QJsonArray selectedList;
   for (Index i = 0; i < mol.atomCount(); ++i) {
     if (mol.atomSelected(i))
       selectedList.append(static_cast<qint64>(i));
   }
-  json.insert("selectedatoms", selectedList);
+  json.insert("selectedAtoms", selectedList);
+
+  // insert the total charge
+  json.insert("charge", mol.totalCharge());
+
+  // insert the spin multiplicity
+  json.insert("spin", mol.totalSpinMultiplicity());
 
   Io::FileFormatManager& formats = Io::FileFormatManager::instance();
   QScopedPointer<Io::FileFormat> format(
     formats.newFormatFromFileExtension(m_moleculeExtension.toStdString()));
+  QScopedPointer<Io::FileFormat> cjsonFormat(
+    formats.newFormatFromFileExtension("cjson"));
 
+  // If we want something *other* than CJSON, check that we can supply that
+  // format
   if (format.isNull()) {
     m_errors << tr("Error writing molecule representation to string: "
                    "Unrecognized file format: %1")
@@ -496,31 +548,35 @@ bool InterfaceScript::insertMolecule(QJsonObject& json,
     return false;
   }
 
+  // if we need a different format, insert it
   if (m_moleculeExtension != QLatin1String("cjson")) {
     json.insert(m_moleculeExtension, QJsonValue(QString::fromStdString(str)));
-  } else {
-    // If cjson was requested, embed the actual JSON, rather than the string.
-    QJsonParseError error;
-    QJsonDocument doc = QJsonDocument::fromJson(str.c_str(), &error);
-    if (error.error != QJsonParseError::NoError) {
-      m_errors << tr("Error generating cjson object: Parse error at offset %1: "
-                     "%2\nRaw JSON:\n\n%3")
-                    .arg(error.offset)
-                    .arg(error.errorString())
-                    .arg(QString::fromStdString(str));
-      return false;
-    }
-
-    if (!doc.isObject()) {
-      m_errors << tr("Error generator cjson object: Parsed JSON is not an "
-                     "object:\n%1")
-                    .arg(QString::fromStdString(str));
-      return false;
-    }
-
-    json.insert(m_moleculeExtension, doc.object());
   }
 
+  // We will *always* write the CJSON representation
+  // Embed CJSON as actual JSON, rather than a string,
+  // .. so we'll have to re-parse it
+  cjsonFormat->writeString(str, mol);
+  QJsonParseError error;
+  QJsonDocument doc = QJsonDocument::fromJson(str.c_str(), &error);
+  if (error.error != QJsonParseError::NoError) {
+    m_errors << tr("Error generating cjson object: Parse error at offset %1: "
+                   "%2\nRaw JSON:\n\n%3")
+                  .arg(error.offset)
+                  .arg(error.errorString())
+                  .arg(QString::fromStdString(str));
+    return false;
+  }
+
+  if (!doc.isObject()) {
+    m_errors << tr("Error generator cjson object: Parsed JSON is not an "
+                   "object:\n%1")
+                  .arg(QString::fromStdString(str));
+    return false;
+  }
+
+  json.insert("cjson", doc.object());
+
   return true;
 }
 
@@ -821,4 +877,4 @@ bool InterfaceScript::parsePattern(const QJsonValue& json,
   return true;
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtGui
