@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTGUI_INTERFACESCRIPT_H
@@ -26,6 +15,7 @@
 #include <QtCore/QJsonObject>
 #include <QtCore/QMap>
 #include <QtCore/QStringList>
+#include <QRegExp>
 
 class QJsonDocument;
 class QProcess;
@@ -201,7 +191,7 @@ class PythonScript;
 }
 ~~~
  * This will result in a QCheckBox in the dynamically generated GUI, with
- * the inital check state shown in `default`.
+ * the initial check state shown in `default`.
  *
  * Special Parameters
  * ------------------
@@ -525,7 +515,7 @@ public:
   void reset();
 
   /**
-   * Request input files from the script using the supplied options object and
+   * Asynchronously run a command script using the supplied options object and
    * molecule. See the class documentation for details on the @p options_
    * object format.
    *
@@ -536,6 +526,11 @@ public:
    */
   bool runCommand(const QJsonObject& options_, Core::Molecule* mol);
 
+  /**
+   * Finish processing an aynchronous command script
+   */
+  bool processCommand(Core::Molecule* mol);
+
   /**
    * Request input files from the script using the supplied options object and
    * molecule. See the class documentation for details on the @p options_
@@ -613,16 +608,24 @@ public:
    */
   QStringList warningList() const { return m_warnings; }
 
+signals:
+  void finished();
+
 public slots:
   /**
    * Enable/disable debugging.
    */
   void setDebug(bool d);
 
+  /**
+   * Receives a signal when asynchronous command scripts are finished
+   */
+  void commandFinished();
+
 private:
   QtGui::PythonScript* m_interpreter;
 
-  void setDefaultPythonInterpretor();
+  void setDefaultPythonInterpreter();
   QByteArray execute(const QStringList& args,
                      const QByteArray& scriptStdin = QByteArray()) const;
   bool parseJson(const QByteArray& json, QJsonDocument& doc) const;
