@@ -26,12 +26,15 @@
 #include <QtCore/QSettings>
 #include <QtCore/QTimer>
 
+#include <QRegularExpression>
+
 namespace Avogadro::QtGui {
 
 JsonWidget::JsonWidget(QWidget* parent_)
   : QWidget(parent_), m_molecule(nullptr), m_currentLayout(nullptr),
-    m_centralWidget(nullptr)
-{}
+    m_centralWidget(nullptr), m_empty(true), m_batchMode(false)
+{
+}
 
 JsonWidget::~JsonWidget() {}
 
@@ -164,7 +167,7 @@ void JsonWidget::buildOptionGui()
       m_currentLayout = layout;
     } else if (m_options["userOptions"].isObject()) {
       userOptions = m_options["userOptions"].toObject();
-      // don't need to set layout, we aready did that
+      // don't need to set layout, we already did that
     } else {
       break;
     }
@@ -175,11 +178,13 @@ void JsonWidget::buildOptionGui()
 
     // File basename next:
     if (userOptions.contains("Filename Base"))
-      addOptionRow("Filename Base", tr("Filename Base"), userOptions.take("Filename Base"));
+      addOptionRow("Filename Base", tr("Filename Base"),
+                   userOptions.take("Filename Base"));
 
     // Number of cores next:
     if (userOptions.contains("Processor Cores"))
-      addOptionRow("Processor Cores", tr("Processor Cores"), userOptions.take("Processor Cores"));
+      addOptionRow("Processor Cores", tr("Processor Cores"),
+                   userOptions.take("Processor Cores"));
 
     // Calculation Type next:
     if (userOptions.contains("Calculation Type"))
@@ -191,19 +196,42 @@ void JsonWidget::buildOptionGui()
                       userOptions);
 
     // Other special cases: Charge / Multiplicity
-    if (userOptions.contains("Charge"))
-      addOptionRow("Charge", tr("Charge"), userOptions.take("Charge"));
-
-    if (userOptions.contains("Multiplicity"))
-      addOptionRow("Multiplicity", tr("Multiplicity"), userOptions.take("Multiplicity"));
+    if (userOptions.contains("Charge") && userOptions.contains("Multiplicity"))
+      combinedOptionRow("Charge", "Multiplicity", tr("Charge"),
+                        tr("Multiplicity"), userOptions, true); // both labels
+    else {
+      if (userOptions.contains("Charge"))
+        addOptionRow("Charge", tr("Charge"), userOptions.take("Charge"));
+      if (userOptions.contains("Multiplicity"))
+        addOptionRow("Multiplicity", tr("Multiplicity"),
+                     userOptions.take("Multiplicity"));
+    }
 
     // Add remaining keys at bottom.
+    // look for "order" key to determine order
+    QMap<int, QString> keys;
+    int order = 0;
     for (QJsonObject::const_iterator it = userOptions.constBegin(),
                                      itEnd = userOptions.constEnd();
          it != itEnd; ++it) {
-      addOptionRow(it.key(), it.key(), it.value());
+      if (it.value().isObject()) {
+        QJsonObject obj = it.value().toObject();
+        if (obj.contains("order") && obj.value("order").isDouble()) {
+          order = obj.value("order").toInt();
+          keys.insert(order, it.key());
+        } else { // object doesn't contain "order"
+          keys.insert(order, it.key());
+          order++;
+        }
+      } else {
+        keys.insert(order++, it.key());
+      }
     }
 
+    // now loop over keys and add them
+    for (QString key : std::as_const(keys))
+      addOptionRow(key, key, userOptions.take(key));
+
     // Make connections for standard options:
     if (auto* combo = qobject_cast<QComboBox*>(
           m_widgets.value("Calculation Type", nullptr))) {
@@ -232,7 +260,7 @@ void JsonWidget::buildOptionGui()
 
 void JsonWidget::combinedOptionRow(const QString& label1, const QString& label2,
                                    const QString& tr1, const QString& tr2,
-                                   QJsonObject& options)
+                                   QJsonObject& options, bool bothLabels)
 {
   if (m_currentLayout == nullptr)
     return;
@@ -246,12 +274,16 @@ void JsonWidget::combinedOptionRow(const QString& label1, const QString& label2,
     if (option1) {
       widget1->setObjectName(label1);
       hbox->addWidget(widget1);
-      m_widgets.insert(tr1, widget1);
+      m_widgets.insert(label1, widget1);
+    }
+    if (bothLabels) {
+      QLabel* label = new QLabel(tr2 + ":");
+      hbox->addWidget(label);
     }
     if (option2) {
-      widget2->setObjectName(label1);
+      widget2->setObjectName(label2);
       hbox->addWidget(widget2);
-      m_widgets.insert(tr2, widget2);
+      m_widgets.insert(label2, widget2);
     }
     hbox->addStretch();
 
@@ -264,7 +296,8 @@ void JsonWidget::combinedOptionRow(const QString& label1, const QString& label2,
   }
 }
 
-void JsonWidget::addOptionRow(const QString& key, const QString& name, const QJsonValue& option)
+void JsonWidget::addOptionRow(const QString& key, const QString& name,
+                              const QJsonValue& option)
 {
   QWidget* widget = createOptionWidget(option);
   if (!widget)
@@ -301,9 +334,9 @@ void JsonWidget::addOptionRow(const QString& key, const QString& name, const QJs
   if (hide) {
     widget->hide();
     // find the label and hide that too
-    auto label = form->labelForField(widget);
-    if (label)
-      label->hide();
+    auto fLabel = form->labelForField(widget);
+    if (fLabel)
+      fLabel->hide();
   }
 }
 
@@ -332,6 +365,8 @@ QWidget* JsonWidget::createOptionWidget(const QJsonValue& option)
     return createFloatWidget(obj);
   else if (type == QLatin1String("boolean"))
     return createBooleanWidget(obj);
+  else if (type == QLatin1String("text"))
+    return createTextWidget(obj);
 
   qDebug() << "Unrecognized option type:" << type;
   return nullptr;
@@ -383,6 +418,19 @@ QWidget* JsonWidget::createStringWidget(const QJsonObject& obj)
   return edit;
 }
 
+QWidget* JsonWidget::createTextWidget(const QJsonObject& obj)
+{
+  auto* text = new QLabel(this);
+  text->setWordWrap(true);
+
+  if (obj.contains(QStringLiteral("toolTip")) &&
+      obj.value(QStringLiteral("toolTip")).isString()) {
+    text->setToolTip(obj[QStringLiteral("toolTip")].toString());
+  }
+
+  return text;
+}
+
 QWidget* JsonWidget::createFilePathWidget(const QJsonObject& obj)
 {
   auto* fileBrowse = new QtGui::FileBrowseWidget(this);
@@ -536,6 +584,8 @@ void JsonWidget::setOption(const QString& name, const QJsonValue& defaultValue)
     return setFloatOption(name, defaultValue);
   else if (type == QLatin1String("boolean"))
     return setBooleanOption(name, defaultValue);
+  else if (type == QLatin1String("text"))
+    return setTextOption(name, defaultValue);
 
   qWarning()
     << tr("Unrecognized option type '%1' for option '%2'.").arg(type).arg(name);
@@ -580,8 +630,7 @@ void JsonWidget::setStringListOption(const QString& name,
 
 void JsonWidget::setStringOption(const QString& name, const QJsonValue& value)
 {
-  auto* lineEdit =
-    qobject_cast<QLineEdit*>(m_widgets.value(name, nullptr));
+  auto* lineEdit = qobject_cast<QLineEdit*>(m_widgets.value(name, nullptr));
   if (!lineEdit) {
     qWarning() << tr("Error setting default for option '%1'. "
                      "Bad widget type.")
@@ -600,6 +649,27 @@ void JsonWidget::setStringOption(const QString& name, const QJsonValue& value)
   lineEdit->setText(value.toString());
 }
 
+void JsonWidget::setTextOption(const QString& name, const QJsonValue& value)
+{
+  auto* text = qobject_cast<QLabel*>(m_widgets.value(name, nullptr));
+  if (text == nullptr) {
+    qWarning() << tr("Error setting default for option '%1'. "
+                     "Bad widget type.")
+                    .arg(name);
+    return;
+  }
+
+  if (!value.isString()) {
+    qWarning() << tr("Error setting default for option '%1'. "
+                     "Bad default value:")
+                    .arg(name)
+               << value;
+    return;
+  }
+
+  text->setText(value.toString());
+}
+
 void JsonWidget::setFilePathOption(const QString& name, const QJsonValue& value)
 {
   auto* fileBrowse =
@@ -646,8 +716,7 @@ void JsonWidget::setIntegerOption(const QString& name, const QJsonValue& value)
 
 void JsonWidget::setFloatOption(const QString& name, const QJsonValue& value)
 {
-  auto* spin =
-    qobject_cast<QDoubleSpinBox*>(m_widgets.value(name, nullptr));
+  auto* spin = qobject_cast<QDoubleSpinBox*>(m_widgets.value(name, nullptr));
   if (!spin) {
     qWarning() << tr("Error setting default for option '%1'. "
                      "Bad widget type.")
@@ -668,8 +737,7 @@ void JsonWidget::setFloatOption(const QString& name, const QJsonValue& value)
 
 void JsonWidget::setBooleanOption(const QString& name, const QJsonValue& value)
 {
-  auto* checkBox =
-    qobject_cast<QCheckBox*>(m_widgets.value(name, nullptr));
+  auto* checkBox = qobject_cast<QCheckBox*>(m_widgets.value(name, nullptr));
   if (!checkBox) {
     qWarning() << tr("Error setting default for option '%1'. "
                      "Bad widget type.")
@@ -730,9 +798,8 @@ QJsonObject JsonWidget::collectOptions() const
       ret.insert(label, value);
     } else if (auto* spinBox = qobject_cast<QSpinBox*>(widget)) {
       ret.insert(label, spinBox->value());
-    } else if (auto* spinBox =
-                 qobject_cast<QDoubleSpinBox*>(widget)) {
-      ret.insert(label, spinBox->value());
+    } else if (auto* doubleSpinBox = qobject_cast<QDoubleSpinBox*>(widget)) {
+      ret.insert(label, doubleSpinBox->value());
     } else if (auto* checkBox = qobject_cast<QCheckBox*>(widget)) {
       ret.insert(label, checkBox->isChecked());
     } else if (auto* fileBrowse =
@@ -769,7 +836,7 @@ QString JsonWidget::generateJobTitle() const
     if (haveTheory)
       theory += "/";
     theory += basis;
-    theory.replace(QRegExp("\\s+"), "");
+    theory.replace(QRegularExpression("\\s+"), "");
     haveTheory = true;
   }
 
@@ -790,4 +857,4 @@ QString JsonWidget::generateJobTitle() const
     .arg(haveTheory ? " | " + theory : QString());
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtGui
