@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2014 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "multiviewwidget.h"
@@ -25,8 +14,7 @@
 #include <QtWidgets/QSplitter>
 #include <QtWidgets/QVBoxLayout>
 
-namespace Avogadro {
-namespace QtGui {
+namespace Avogadro::QtGui {
 
 class ActiveWidgetFilter : public QObject
 {
@@ -72,7 +60,7 @@ void MultiViewWidget::addWidget(QWidget* widget)
     ContainerWidget* container = createContainer(widget);
     m_children << container;
     if (m_children.size() == 1) {
-      QVBoxLayout* widgetLayout = qobject_cast<QVBoxLayout*>(layout());
+      auto* widgetLayout = qobject_cast<QVBoxLayout*>(layout());
       if (!widgetLayout) {
         widgetLayout = new QVBoxLayout;
         widgetLayout->setContentsMargins(0, 0, 0, 0);
@@ -111,25 +99,25 @@ void MultiViewWidget::setActiveWidget(QWidget* widget)
 
 void MultiViewWidget::splitHorizontal()
 {
-  ContainerWidget* container = qobject_cast<ContainerWidget*>(sender());
+  auto* container = qobject_cast<ContainerWidget*>(sender());
   if (container)
     splitView(Qt::Horizontal, container);
 }
 
 void MultiViewWidget::splitVertical()
 {
-  ContainerWidget* container = qobject_cast<ContainerWidget*>(sender());
+  auto* container = qobject_cast<ContainerWidget*>(sender());
   if (container)
     splitView(Qt::Vertical, container);
 }
 
 void MultiViewWidget::createView()
 {
-  QPushButton* button = qobject_cast<QPushButton*>(sender());
+  auto* button = qobject_cast<QPushButton*>(sender());
   if (m_factory && button && button->parentWidget() &&
       button->parentWidget()->parentWidget()) {
     QWidget* optionsWidget = button->parentWidget();
-    ContainerWidget* container =
+    auto* container =
       qobject_cast<ContainerWidget*>(optionsWidget->parentWidget());
     if (container) {
       auto widget = m_factory->createView(button->property("name").toString());
@@ -146,13 +134,13 @@ void MultiViewWidget::createView()
 
 void MultiViewWidget::removeView()
 {
-  ContainerWidget* container = qobject_cast<ContainerWidget*>(sender());
+  auto* container = qobject_cast<ContainerWidget*>(sender());
   if (container) {
-    QSplitter* splitter = qobject_cast<QSplitter*>(container->parent());
+    auto* splitter = qobject_cast<QSplitter*>(container->parent());
     if (splitter && splitter->count() == 2) {
       // Get its parent, and insert the other widget into it, delete this
       // widget.
-      QSplitter* splitterParent = qobject_cast<QSplitter*>(splitter->parent());
+      auto* splitterParent = qobject_cast<QSplitter*>(splitter->parent());
       QWidget* moveWidget = splitter->widget(0);
       if (moveWidget == container)
         moveWidget = splitter->widget(1);
@@ -163,7 +151,7 @@ void MultiViewWidget::removeView()
         splitter->deleteLater();
       } else if (splitter->parent() == this) {
         // No more splits - back to single view widget.
-        QVBoxLayout* layoutParent = qobject_cast<QVBoxLayout*>(layout());
+        auto* layoutParent = qobject_cast<QVBoxLayout*>(layout());
         if (layoutParent) {
           layoutParent->addWidget(moveWidget);
           layoutParent->removeWidget(splitter);
@@ -172,7 +160,7 @@ void MultiViewWidget::removeView()
       }
     } else if (container->parent() == this) {
       // Delete the current container, and create the option container.
-      QVBoxLayout* vLayout = qobject_cast<QVBoxLayout*>(layout());
+      auto* vLayout = qobject_cast<QVBoxLayout*>(layout());
       container->deleteLater();
       ContainerWidget* newContainer = createContainer();
       vLayout->addWidget(newContainer);
@@ -183,7 +171,7 @@ void MultiViewWidget::removeView()
 
 ContainerWidget* MultiViewWidget::createContainer(QWidget* widget)
 {
-  ContainerWidget* container = new ContainerWidget;
+  auto* container = new ContainerWidget;
   connect(container, SIGNAL(splitHorizontal()), SLOT(splitHorizontal()));
   connect(container, SIGNAL(splitVertical()), SLOT(splitVertical()));
   connect(container, SIGNAL(closeView()), SLOT(removeView()));
@@ -193,16 +181,16 @@ ContainerWidget* MultiViewWidget::createContainer(QWidget* widget)
   }
   // If we have a factory, then create the options widget too!
   else if (m_factory) {
-    QWidget* optionsWidget = new QWidget;
-    QVBoxLayout* v = new QVBoxLayout;
+    auto* optionsWidget = new QWidget;
+    auto* v = new QVBoxLayout;
     optionsWidget->setLayout(v);
     v->addStretch();
     foreach (const QString& name, m_factory->views()) {
-      QPushButton* button = new QPushButton(name);
+      auto* button = new QPushButton(name);
       button->setProperty("name", name);
       button->setToolTip(tr("Create a new view"));
       connect(button, SIGNAL(clicked()), SLOT(createView()));
-      QHBoxLayout* h = new QHBoxLayout;
+      auto* h = new QHBoxLayout;
       h->addStretch();
       h->addWidget(button);
       h->addStretch();
@@ -218,13 +206,13 @@ ContainerWidget* MultiViewWidget::createContainer(QWidget* widget)
 void MultiViewWidget::splitView(Qt::Orientation orient,
                                 ContainerWidget* container)
 {
-  QVBoxLayout* widgetLayout = qobject_cast<QVBoxLayout*>(container->parent());
-  QSplitter* split = qobject_cast<QSplitter*>(container->parent());
+  auto* widgetLayout = qobject_cast<QVBoxLayout*>(container->parent());
+  auto* split = qobject_cast<QSplitter*>(container->parent());
   if (!widgetLayout)
     if (container->parent() == this)
       widgetLayout = qobject_cast<QVBoxLayout*>(layout());
   if (widgetLayout) {
-    QSplitter* splitter = new QSplitter(orient, this);
+    auto* splitter = new QSplitter(orient, this);
     widgetLayout->removeWidget(container);
     widgetLayout->addWidget(splitter);
     splitter->addWidget(container);
@@ -236,7 +224,7 @@ void MultiViewWidget::splitView(Qt::Orientation orient,
     sizes << s << s;
     splitter->setSizes(sizes);
   } else if (split) {
-    QSplitter* splitter = new QSplitter(orient, this);
+    auto* splitter = new QSplitter(orient, this);
     int idx = split->indexOf(container);
     splitter->addWidget(container);
     container = createContainer();
@@ -250,7 +238,6 @@ void MultiViewWidget::splitView(Qt::Orientation orient,
   }
 }
 
-} // End QtGui namespace
 } // End Avogadro namespace
 
 #include "multiviewwidget.moc"
