@@ -40,11 +40,18 @@ public:
 
   QStringList menuPath(QAction* action) const override;
 
+  bool handleCommand(const QString& command,
+                     const QVariantMap& options) override;
+
+  void registerCommands() override;
+
 public slots:
   void setMolecule(QtGui::Molecule* mol) override;
 
 private slots:
   void bond();
+  void createBond();
+  void bondOrders();
   void clearBonds();
   void configure();
   void setValues();
@@ -56,8 +63,10 @@ private:
   double m_minDistance;
 
   QAction* m_action;
+  QAction* m_orderAction;
   QAction* m_clearAction;
   QAction* m_configAction;
+  QAction* m_createBondsAction;
 
   QDialog* m_dialog;
   Ui::BondingDialog* m_ui;
