@@ -12,10 +12,8 @@
 #include <avogadro/rendering/groupnode.h>
 #include <avogadro/rendering/spheregeometry.h>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
-using Core::Elements;
 using QtGui::Molecule;
 using QtGui::PluginLayerManager;
 using Rendering::CylinderGeometry;
@@ -37,9 +35,9 @@ void Licorice::process(const Molecule& molecule, Rendering::GroupNode& node)
   float selectedRadius(radius * 2.0f);
 
   // Add a sphere node to contain all of the spheres.
-  GeometryNode* geometry = new GeometryNode;
+  auto* geometry = new GeometryNode;
   node.addChild(geometry);
-  SphereGeometry* spheres = new SphereGeometry;
+  auto* spheres = new SphereGeometry;
   spheres->identifier().molecule = &molecule;
   spheres->identifier().type = Rendering::AtomType;
   auto selectedSpheres = new SphereGeometry;
@@ -62,7 +60,7 @@ void Licorice::process(const Molecule& molecule, Rendering::GroupNode& node)
     }
   }
 
-  CylinderGeometry* cylinders = new CylinderGeometry;
+  auto* cylinders = new CylinderGeometry;
   cylinders->identifier().molecule = &molecule;
   cylinders->identifier().type = Rendering::BondType;
   geometry->addDrawable(cylinders);
@@ -84,5 +82,4 @@ void Licorice::process(const Molecule& molecule, Rendering::GroupNode& node)
   }
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
