@@ -28,10 +28,10 @@
 
 #include <avogadro/core/angletools.h>
 
+#include <QAction>
 #include <QtGui/QGuiApplication>
 #include <QtGui/QIcon>
 #include <QtGui/QMouseEvent>
-#include <QtWidgets/QAction>
 
 #include <QDebug>
 
@@ -52,7 +52,6 @@ MeasureTool::MeasureTool(QObject* parent_)
     m_molecule(nullptr), m_rwMolecule(nullptr), m_renderer(nullptr)
 {
   m_activateAction->setText(tr("Measure"));
-  m_activateAction->setIcon(QIcon(":/icons/measuretool.png"));
   m_activateAction->setToolTip(
     tr("Measure Tool\n\n"
        "Left Mouse: \tSelect up to four Atoms.\n"
@@ -60,10 +59,19 @@ MeasureTool::MeasureTool(QObject* parent_)
        "\tAngle is measured between 1-3 using 2 as the common point\n"
        "\tDihedral is measured between 1-2-3-4\n"
        "Right Mouse: \tReset the measurements."));
+  setIcon();
 }
 
 MeasureTool::~MeasureTool() {}
 
+void MeasureTool::setIcon(bool darkTheme)
+{
+  if (darkTheme)
+    m_activateAction->setIcon(QIcon(":/icons/measure_dark.svg"));
+  else
+    m_activateAction->setIcon(QIcon(":/icons/measure_light.svg"));
+}
+
 QWidget* MeasureTool::toolWidget() const
 {
   return nullptr;
@@ -172,12 +180,15 @@ void MeasureTool::draw(Rendering::GroupNode& node)
     case 4:
       v3 = positions[3] - positions[2];
       v3Norm = v3.norm();
+      [[fallthrough]];
     case 3:
       v2 = positions[2] - positions[1];
       v2Norm = v2.norm();
+      [[fallthrough]];
     case 2:
       v1 = positions[1] - positions[0];
       v1Norm = v1.norm();
+      [[fallthrough]];
     default:
       break;
   }
@@ -276,4 +287,4 @@ bool MeasureTool::toggleAtom(const Rendering::Identifier& atom)
   return true;
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtPlugins
