@@ -5,6 +5,7 @@
 
 #include "openbabel.h"
 
+#include "conformersearchdialog.h"
 #include "obcharges.h"
 #include "obfileformat.h"
 #include "obforcefielddialog.h"
@@ -21,12 +22,14 @@
 #include <QtCore/QSettings>
 #include <QtCore/QTimer>
 
-#include <QtWidgets/QAction>
+#include <QAction>
 #include <QtWidgets/QFileDialog>
 #include <QtWidgets/QInputDialog>
 #include <QtWidgets/QMessageBox>
 #include <QtWidgets/QProgressDialog>
 
+#include <QRegularExpression>
+
 #include <string>
 
 using Avogadro::QtGui::Molecule;
@@ -36,12 +39,12 @@ namespace Avogadro::QtPlugins {
 OpenBabel::OpenBabel(QObject* p)
   : ExtensionPlugin(p), m_molecule(nullptr), m_process(new OBProcess(this)),
     m_readFormatsPending(true), m_writeFormatsPending(true),
-    m_defaultFormat("cml"), m_progress(nullptr)
+    m_defaultFormat("cml"), m_progress(nullptr),
+    m_conformerSearchDialog(nullptr)
 {
   auto* action = new QAction(this);
   action->setEnabled(true);
   action->setText(tr("Optimize Geometry"));
-  action->setShortcut(QKeySequence("Ctrl+Alt+O"));
   connect(action, SIGNAL(triggered()), SLOT(onOptimizeGeometry()));
   m_actions.push_back(action);
 
@@ -51,6 +54,12 @@ OpenBabel::OpenBabel(QObject* p)
   connect(action, SIGNAL(triggered()), SLOT(onConfigureGeometryOptimization()));
   m_actions.push_back(action);
 
+  action = new QAction(this);
+  action->setEnabled(true);
+  action->setText(tr("Conformer Search…"));
+  connect(action, SIGNAL(triggered()), SLOT(onConfigureConformerSearch()));
+  m_actions.push_back(action);
+
   action = new QAction(this);
   action->setEnabled(true);
   action->setText(tr("Perceive Bonds"));
@@ -81,16 +90,14 @@ OpenBabel::OpenBabel(QObject* p)
   refreshCharges();
 
   QString info = openBabelInfo();
-  /*
   if (info.isEmpty()) {
     qWarning() << tr("%1 not found! Disabling Open Babel plugin actions.")
                     .arg(OBProcess().obabelExecutable());
     foreach (QAction* a, m_actions)
       a->setEnabled(false);
   } else {
-  */
-  qDebug() << OBProcess().obabelExecutable() << " found: " << info;
-  // }
+    qDebug() << OBProcess().obabelExecutable() << " found: " << info;
+  }
 }
 
 OpenBabel::~OpenBabel() {}
@@ -123,9 +130,13 @@ QList<Io::FileFormat*> OpenBabel::fileFormats() const
   std::vector<std::string> fexts;
   std::vector<std::string> fmime;
 
+  // Simple lambda to replace toSet in QList
+  auto toSet = [&](const QList<QString>& list) {
+    return QSet<QString>(list.begin(), list.end());
+  };
   QSet<QString> formatDescriptions;
-  formatDescriptions.unite(m_readFormats.uniqueKeys().toSet());
-  formatDescriptions.unite(m_writeFormats.uniqueKeys().toSet());
+  formatDescriptions.unite(toSet(m_readFormats.uniqueKeys()));
+  formatDescriptions.unite(toSet(m_writeFormats.uniqueKeys()));
 
   QSet<QString> formatExtensions;
 
@@ -148,11 +159,11 @@ QList<Io::FileFormat*> OpenBabel::fileFormats() const
     Io::FileFormat::Operations rw = Io::FileFormat::None;
 
     if (m_readFormats.contains(qdesc)) {
-      formatExtensions.unite(m_readFormats.values(qdesc).toSet());
+      formatExtensions.unite(toSet(m_readFormats.values(qdesc)));
       rw |= Io::FileFormat::Read;
     }
     if (m_writeFormats.contains(qdesc)) {
-      formatExtensions.unite(m_writeFormats.values(qdesc).toSet());
+      formatExtensions.unite(toSet(m_writeFormats.values(qdesc)));
       rw |= Io::FileFormat::Write;
     }
 
@@ -230,13 +241,13 @@ void OpenBabel::refreshReadFormats()
   // process for the refresh methods.
   auto* proc = new OBProcess(this);
 
-  connect(proc, SIGNAL(queryReadFormatsFinished(QMap<QString, QString>)),
-          SLOT(handleReadFormatUpdate(QMap<QString, QString>)));
+  connect(proc, SIGNAL(queryReadFormatsFinished(QMultiMap<QString, QString>)),
+          SLOT(handleReadFormatUpdate(QMultiMap<QString, QString>)));
 
   proc->queryReadFormats();
 }
 
-void OpenBabel::handleReadFormatUpdate(const QMap<QString, QString>& fmts)
+void OpenBabel::handleReadFormatUpdate(const QMultiMap<QString, QString>& fmts)
 {
   m_readFormatsPending = false;
 
@@ -255,6 +266,8 @@ void OpenBabel::handleReadFormatUpdate(const QMap<QString, QString>& fmts)
     if (m_readFormats.contains("Chemical JSON") &&
         m_writeFormats.contains("Chemical JSON")) {
       m_defaultFormat = "cjson";
+
+      qDebug() << "Setting default format to cjson.";
     }
   }
 }
@@ -265,13 +278,13 @@ void OpenBabel::refreshWriteFormats()
   // process for the refresh methods.
   auto* proc = new OBProcess(this);
 
-  connect(proc, SIGNAL(queryWriteFormatsFinished(QMap<QString, QString>)),
-          SLOT(handleWriteFormatUpdate(QMap<QString, QString>)));
+  connect(proc, SIGNAL(queryWriteFormatsFinished(QMultiMap<QString, QString>)),
+          SLOT(handleWriteFormatUpdate(QMultiMap<QString, QString>)));
 
   proc->queryWriteFormats();
 }
 
-void OpenBabel::handleWriteFormatUpdate(const QMap<QString, QString>& fmts)
+void OpenBabel::handleWriteFormatUpdate(const QMultiMap<QString, QString>& fmts)
 {
   m_writeFormatsPending = false;
 
@@ -290,6 +303,7 @@ void OpenBabel::handleWriteFormatUpdate(const QMap<QString, QString>& fmts)
     if (m_readFormats.contains("Chemical JSON") &&
         m_writeFormats.contains("Chemical JSON")) {
       m_defaultFormat = "cjson";
+      qDebug() << "Setting default format to cjson.";
     }
   }
 }
@@ -300,13 +314,14 @@ void OpenBabel::refreshForceFields()
   // process for the refresh methods.
   auto* proc = new OBProcess(this);
 
-  connect(proc, SIGNAL(queryForceFieldsFinished(QMap<QString, QString>)),
-          SLOT(handleForceFieldsUpdate(QMap<QString, QString>)));
+  connect(proc, SIGNAL(queryForceFieldsFinished(QMultiMap<QString, QString>)),
+          SLOT(handleForceFieldsUpdate(QMultiMap<QString, QString>)));
 
   proc->queryForceFields();
 }
 
-void OpenBabel::handleForceFieldsUpdate(const QMap<QString, QString>& ffMap)
+void OpenBabel::handleForceFieldsUpdate(
+  const QMultiMap<QString, QString>& ffMap)
 {
   auto* proc = qobject_cast<OBProcess*>(sender());
   if (proc)
@@ -321,13 +336,14 @@ void OpenBabel::refreshCharges()
   // process for the refresh methods.
   auto* proc = new OBProcess(this);
 
-  connect(proc, SIGNAL(queryChargesFinished(QMap<QString, QString>)),
-          SLOT(handleChargesUpdate(QMap<QString, QString>)));
+  connect(proc, SIGNAL(queryChargesFinished(QMultiMap<QString, QString>)),
+          SLOT(handleChargesUpdate(QMultiMap<QString, QString>)));
 
   proc->queryCharges();
 }
 
-void OpenBabel::handleChargesUpdate(const QMap<QString, QString>& chargeMap)
+void OpenBabel::handleChargesUpdate(
+  const QMultiMap<QString, QString>& chargeMap)
 {
   auto* proc = qobject_cast<OBProcess*>(sender());
   if (proc)
@@ -373,6 +389,33 @@ void OpenBabel::onConfigureGeometryOptimization()
   settings.setValue("openbabel/optimizeGeometry/lastOptions", options);
 }
 
+void OpenBabel::onConfigureConformerSearch()
+{
+  // If the force field map is empty, there is probably a problem with the
+  // obabel executable. Warn the user and return.
+  if (m_forceFields.isEmpty()) {
+    QMessageBox::critical(qobject_cast<QWidget*>(parent()), tr("Error"),
+                          tr("An error occurred while retrieving the list of "
+                             "supported forcefields. (using '%1').")
+                            .arg(m_process->obabelExecutable()),
+                          QMessageBox::Ok);
+    return;
+  }
+
+  QSettings settings;
+  QStringList options =
+    settings.value("openbabel/conformerSearch/lastOptions").toStringList();
+
+  if (m_conformerSearchDialog == nullptr) {
+    m_conformerSearchDialog =
+      new ConformerSearchDialog(qobject_cast<QWidget*>(parent()));
+    connect(m_conformerSearchDialog, SIGNAL(accepted()), this,
+            SLOT(onGenerateConformers()));
+  }
+  // todo set options from last run
+  m_conformerSearchDialog->show();
+}
+
 void OpenBabel::onOptimizeGeometry()
 {
   if (!m_molecule || m_molecule->atomCount() == 0) {
@@ -421,7 +464,7 @@ void OpenBabel::onOptimizeGeometry()
 
   // Setup progress dialog
   initializeProgressDialog(tr("Optimizing Geometry (Open Babel)"),
-                           tr("Generating MDL…"), 0, 0, 0);
+                           tr("Generating…"), 0, 0, 0);
 
   // Connect process
   disconnect(m_process);
@@ -518,6 +561,158 @@ void OpenBabel::onOptimizeGeometryFinished(const QByteArray& output)
   m_progress->reset();
 }
 
+void OpenBabel::onGenerateConformers()
+{
+  if (!m_molecule || m_molecule->atomCount() == 0) {
+    QMessageBox::critical(qobject_cast<QWidget*>(parent()), tr("Error"),
+                          tr("Molecule invalid. Cannot generate conformers."),
+                          QMessageBox::Ok);
+    return;
+  }
+
+  // If the force field map is empty, there is probably a problem with the
+  // obabel executable. Warn the user and return.
+  if (m_forceFields.isEmpty()) {
+    QMessageBox::critical(qobject_cast<QWidget*>(parent()), tr("Error"),
+                          tr("An error occurred while retrieving the list of "
+                             "supported forcefields. (using '%1').")
+                            .arg(m_process->obabelExecutable()),
+                          QMessageBox::Ok);
+    return;
+  }
+
+  // Fail here if the process is already in use
+  if (m_process->inUse()) {
+    showProcessInUseError(tr("Cannot generate conformers with Open Babel."));
+    return;
+  }
+
+  if (m_conformerSearchDialog == nullptr) {
+    return; // should't happen
+  }
+
+  QSettings settings;
+  QStringList options = m_conformerSearchDialog->options();
+
+  QStringList ffOptions =
+    settings.value("openbabel/optimizeGeometry/lastOptions").toStringList();
+  bool autoDetect =
+    settings.value("openbabel/optimizeGeometry/autoDetect", true).toBool();
+
+  if (autoDetect) {
+    QString ff = autoDetectForceField();
+    int ffIndex = ffOptions.indexOf("--ff");
+    if (ffIndex >= 0) {
+      // Shouldn't happen, but just to be safe...
+      if (ffIndex + 1 == ffOptions.size())
+        ffOptions << ff;
+      else
+        ffOptions[ffIndex + 1] = ff;
+    } else {
+      ffOptions << "--ff" << ff;
+    }
+  }
+
+  options << ffOptions;
+
+  // Setup progress dialog
+  initializeProgressDialog(tr("Generating Conformers (Open Babel)"),
+                           tr("Generating…"), 0, 0, 0);
+
+  // Connect process
+  disconnect(m_process);
+  m_process->disconnect(this);
+  connect(m_progress, SIGNAL(canceled()), m_process, SLOT(abort()));
+  connect(m_process, SIGNAL(conformerStatusUpdate(int, int, double, double)),
+          SLOT(onConformerStatusUpdate(int, int, double, double)));
+  connect(m_process, SIGNAL(generateConformersFinished(QByteArray)),
+          SLOT(onGenerateConformersFinished(QByteArray)));
+
+  std::string mol;
+  if (!Io::FileFormatManager::instance().writeString(*m_molecule, mol,
+                                                     m_defaultFormat)) {
+    m_progress->reset();
+    QMessageBox::critical(
+      qobject_cast<QWidget*>(parent()), tr("Error"),
+      tr("An internal error occurred while generating an "
+         "Open Babel representation of the current molecule."),
+      QMessageBox::Ok);
+    return;
+  }
+
+  m_progress->setLabelText(tr("Starting %1…", "arg is an executable file.")
+                             .arg(m_process->obabelExecutable()));
+
+  // Run obabel
+  m_process->generateConformers(QByteArray(mol.c_str()), options,
+                                m_defaultFormat);
+}
+
+void OpenBabel::onConformerStatusUpdate(int step, int numSteps, double energy,
+                                        double lastEnergy)
+{
+  QString status;
+
+  if (step == 0) {
+    status = tr("Step %1 of %2\nCurrent energy: %3\ndE: %4")
+               .arg(step)
+               .arg(numSteps)
+               .arg(fabs(energy) > 1e-10 ? QString::number(energy, 'g', 5)
+                                         : QString("(pending)"))
+               .arg("(pending)");
+  } else {
+    double dE = energy - lastEnergy;
+    status = tr("Step %1 of %2\nCurrent energy: %3\ndE: %4")
+               .arg(step)
+               .arg(numSteps)
+               .arg(energy, 0, 'g', 5)
+               .arg(dE, 0, 'g', 5);
+  }
+
+  m_progress->setRange(0, numSteps);
+  m_progress->setValue(step);
+  m_progress->setLabelText(status);
+}
+
+void OpenBabel::onGenerateConformersFinished(const QByteArray& output)
+{
+  m_progress->setLabelText(tr("Updating molecule…"));
+
+  // output --> molecule
+  Core::Molecule mol;
+  if (!Io::FileFormatManager::instance().readString(mol, output.constData(),
+                                                    m_defaultFormat)) {
+    m_progress->reset();
+    QMessageBox::critical(qobject_cast<QWidget*>(parent()), tr("Error"),
+                          tr("Error interpreting Open Babel output."),
+                          QMessageBox::Ok);
+    qDebug() << "Open Babel:" << output;
+    return;
+  }
+
+  /// @todo cache a pointer to the current molecule in the above slot, and
+  /// verify that we're still operating on the same molecule.
+
+  // Check that the atom count hasn't changed:
+  if (mol.atomCount() != m_molecule->atomCount()) {
+    m_progress->reset();
+    QMessageBox::critical(qobject_cast<QWidget*>(parent()), tr("Error"),
+                          tr("Number of atoms in obabel output (%1) does not "
+                             "match the number of atoms in the original "
+                             "molecule (%2).")
+                            .arg(mol.atomCount())
+                            .arg(m_molecule->atomCount()),
+                          QMessageBox::Ok);
+    return;
+  }
+
+  //@todo .. multiple coordinate sets
+  m_molecule->undoMolecule()->setAtomPositions3d(mol.atomPositions3d(),
+                                                 tr("Generate Conformers"));
+  m_molecule->emitChanged(QtGui::Molecule::Atoms | QtGui::Molecule::Modified);
+  m_progress->reset();
+}
+
 void OpenBabel::onPerceiveBonds()
 {
   // Fail here if the process is already in use
@@ -819,7 +1014,7 @@ QString OpenBabel::autoDetectForceField() const
   // http://forums.openbabel.org/Heuristic-for-selecting-best-forcefield-td4655917.html
   QString formula = QString::fromStdString(m_molecule->formula());
   QStringList elementTypes =
-    formula.split(QRegExp("\\d+"), QString::SkipEmptyParts);
+    formula.split(QRegularExpression("\\d+"), Qt::SkipEmptyParts);
   bool mmff94Valid = true;
   bool gaffValid = true;
   QStringList::const_iterator eleIter = elementTypes.constBegin();
@@ -830,13 +1025,10 @@ QString OpenBabel::autoDetectForceField() const
         *eleIter != "N" && *eleIter != "O" && *eleIter != "P" &&
         *eleIter != "S") {
       gaffValid = false;
+      mmff94Valid = false;
 
-      // These are supported by MMFF94 (but not GAFF)
-      if (*eleIter != "Fe" && *eleIter != "Li" && *eleIter != "Na" &&
-          *eleIter != "K" && *eleIter != "Zn" && *eleIter != "Ca" &&
-          *eleIter != "Cu" && *eleIter != "Mg" && *eleIter != "Na") {
-        mmff94Valid = false;
-      }
+      // MMFF94 supports isolated metal ions but it's safer to use UFF
+      // Fixes #1324
     }
     ++eleIter;
   }
@@ -856,4 +1048,4 @@ QString OpenBabel::autoDetectForceField() const
 
   return result;
 }
-} // namespace Avogadro
+} // namespace Avogadro::QtPlugins
