@@ -10,12 +10,16 @@
 
 class QAction;
 class QDialog;
-class QTimer;
 
 namespace Avogadro {
+
+namespace VTK {
+class ChartDialog;
+}
+
 namespace QtPlugins {
 
-class VibrationDialog;
+class SpectraDialog;
 
 /**
  * @brief The Spectra plugin handles vibrations and spectra.
@@ -29,12 +33,9 @@ public:
   explicit Spectra(QObject* parent = nullptr);
   ~Spectra() override;
 
-  QString name() const override { return tr("Spectra and Vibrations"); }
+  QString name() const override { return tr("Spectra"); }
 
-  QString description() const override
-  {
-    return tr("Display spectra and vibrational modes.");
-  }
+  QString description() const override { return tr("Display spectra plots."); }
 
   QList<QAction*> actions() const override;
 
@@ -43,30 +44,19 @@ public:
   void setMolecule(QtGui::Molecule* mol) override;
 
 public slots:
-  void setMode(int mode);
-  void setAmplitude(int amplitude);
-  void startVibrationAnimation();
-  void stopVibrationAnimation();
-  void openDialog();
 
-private slots:
-  void advanceFrame();
+  void openDialog();
+  void moleculeChanged(unsigned int changes);
 
 private:
+  void gatherSpectra();
+
   QList<QAction*> m_actions;
-
   QtGui::Molecule* m_molecule;
-
-  VibrationDialog* m_dialog;
-
-  QTimer* m_timer;
-
-  int m_currentFrame;
-  int m_totalFrames;
-  int m_mode;
-  int m_amplitude;
+  SpectraDialog* m_dialog;
 };
-}
-}
+
+} // namespace QtPlugins
+} // namespace Avogadro
 
 #endif // AVOGADRO_QTPLUGINS_Spectra_H
