@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "slatersetconcurrent.h"
@@ -25,8 +14,7 @@
 
 #include <QtConcurrent/QtConcurrentMap>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 using Core::SlaterSet;
 using Core::SlaterSetTools;
@@ -57,7 +45,7 @@ void SlaterSetConcurrent::setMolecule(Core::Molecule* mol)
   if (!mol)
     return;
   m_set = dynamic_cast<SlaterSet*>(mol->basisSet());
-  if (m_tools)
+  
     delete m_tools;
   m_tools = new SlaterSetTools(mol);
 }
@@ -134,4 +122,3 @@ void SlaterSetConcurrent::processSpinDensity(SlaterShell& shell)
   shell.tCube->setValue(shell.pos, shell.tools->calculateSpinDensity(pos));
 }
 }
-}
