@@ -6,8 +6,6 @@
 #include "surfaces.h"
 #include "surfacedialog.h"
 
-#include "tinycolormap.hpp"
-
 #include "gaussiansetconcurrent.h"
 #include "slatersetconcurrent.h"
 
@@ -40,28 +38,34 @@ namespace {
 #include <avogadro/quantumio/gamessus.h>
 #include <avogadro/quantumio/gaussiancube.h>
 #include <avogadro/quantumio/gaussianfchk.h>
+#include <avogadro/quantumio/genericoutput.h>
 #include <avogadro/quantumio/molden.h>
 #include <avogadro/quantumio/mopacaux.h>
 #include <avogadro/quantumio/nwchemjson.h>
 #include <avogadro/quantumio/nwchemlog.h>
+#include <avogadro/quantumio/orca.h>
 
+#include <QAction>
+#include <QOpenGLFramebufferObject>
 #include <QtConcurrent/QtConcurrentMap>
 #include <QtConcurrent/QtConcurrentRun>
 #include <QtCore/QBuffer>
 #include <QtCore/QCoreApplication>
 #include <QtCore/QDebug>
 #include <QtCore/QProcess>
-#include <QtGui/QOpenGLFramebufferObject>
-#include <QtWidgets/QAction>
 #include <QtWidgets/QFileDialog>
 #include <QtWidgets/QMessageBox>
 #include <QtWidgets/QProgressDialog>
 
+#include <QGuiApplication>
+#include <QScreen>
+
 using namespace tinycolormap;
 
 namespace Avogadro::QtPlugins {
 
 using Core::Array;
+using Core::Cube;
 using Core::GaussianSet;
 using Core::NeighborPerceiver;
 using QtGui::Molecule;
@@ -80,27 +84,149 @@ Surfaces::Surfaces(QObject* p) : ExtensionPlugin(p), d(new PIMPL())
   connect(action, SIGNAL(triggered()), SLOT(surfacesActivated()));
   connect(&m_displayMeshWatcher, SIGNAL(finished()), SLOT(displayMesh()));
   connect(&m_performEDTStepWatcher, SIGNAL(finished()), SLOT(performEDTStep()));
-  
+
   m_actions.push_back(action);
 
   // Register quantum file formats
   Io::FileFormatManager::registerFormat(new QuantumIO::GAMESSUSOutput);
   Io::FileFormatManager::registerFormat(new QuantumIO::GaussianFchk);
   Io::FileFormatManager::registerFormat(new QuantumIO::GaussianCube);
+  Io::FileFormatManager::registerFormat(new QuantumIO::GenericOutput);
   Io::FileFormatManager::registerFormat(new QuantumIO::MoldenFile);
   Io::FileFormatManager::registerFormat(new QuantumIO::MopacAux);
   Io::FileFormatManager::registerFormat(new QuantumIO::NWChemJson);
   Io::FileFormatManager::registerFormat(new QuantumIO::NWChemLog);
+  Io::FileFormatManager::registerFormat(new QuantumIO::ORCAOutput);
 }
 
 Surfaces::~Surfaces()
 {
   delete d;
-  delete m_cube;
+  // delete m_cube; // should be freed by the molecule
+}
+
+void Surfaces::registerCommands()
+{
+  // register some scripting commands
+  emit registerCommand("renderVDW", tr("Render the van der Waals surface."));
+  emit registerCommand("renderVanDerWaals",
+                       tr("Render the van der Waals molecular surface."));
+  emit registerCommand("renderSolventAccessible",
+                       tr("Render the solvent-accessible molecular surface."));
+  emit registerCommand("renderSolventExcluded",
+                       tr("Render the solvent-excluded molecular surface."));
+  emit registerCommand("renderOrbital", tr("Render a molecular orbital."));
+  emit registerCommand("renderMO", tr("Render a molecular orbital."));
+  emit registerCommand("renderElectronDensity",
+                       tr("Render the electron density."));
+  emit registerCommand("renderSpinDensity", tr("Render the spin density."));
+  emit registerCommand("renderCube",
+                       tr("Render a cube supplied with the file."));
+}
+
+bool Surfaces::handleCommand(const QString& command, const QVariantMap& options)
+{
+  if (m_molecule == nullptr)
+    return false; // No molecule to handle the command.
+
+  // Set up some defaults for the options.
+  int index = -1;
+  int homo = -1;
+  float isoValue = 0.03;
+  float cubeResolution = resolution(); // use default resolution
+
+  if (options.contains("resolution") &&
+      options["resolution"].canConvert<float>()) {
+    bool ok;
+    float res = options["resolution"].toFloat(&ok);
+    if (ok)
+      cubeResolution = res;
+  }
+  if (options.contains("isovalue") && options["isovalue"].canConvert<float>()) {
+    bool ok;
+    float iso = options["isovalue"].toFloat(&ok);
+    if (ok)
+      isoValue = iso;
+  }
+
+  if (m_basis != nullptr)
+    homo = m_basis->homo();
+  if (options.contains("orbital")) {
+    // check if options contains "homo" or "lumo"
+    bool ok = false;
+    if (options["orbital"].canConvert<int>()) {
+      // internally, we count orbitals from zero
+      // if the conversion worked, ok = true
+      // and we'll skip the next conditional
+      index = options.value("orbital").toInt(&ok) - 1;
+    }
+    if (!ok && options["orbital"].canConvert<QString>()) {
+      // should be something like "homo-1" or "lumo+2"
+      QString name = options["orbital"].toString();
+      QString expression, modifier;
+      if (name.contains("homo", Qt::CaseInsensitive)) {
+        index = homo; // modified by the expression after the string
+        expression = name.remove("homo", Qt::CaseInsensitive);
+      } else if (name.contains("lumo", Qt::CaseInsensitive)) {
+        index = homo + 1; // again modified by the expression
+        expression = name.remove("lumo", Qt::CaseInsensitive);
+      }
+      // modify HOMO / LUMO based on "+ number" or "- number"
+      if (expression.contains('-')) {
+        modifier = expression.remove('-');
+        bool ok;
+        int n = modifier.toInt(&ok);
+        if (ok)
+          index = index - n;
+      } else if (expression.contains('+')) {
+        modifier = expression.remove('+');
+        bool ok;
+        int n = modifier.toInt(&ok);
+        if (ok)
+          index = index + n;
+      }
+      index = index - 1; // start from zero
+    }
+  }
+  bool beta = false;
+  if (options.contains("spin")) {
+    beta = options["spin"].toString().contains("beta");
+  }
+
+  if ((command.compare("renderVanDerWaals", Qt::CaseInsensitive) == 0) ||
+      (command.compare("renderVDW", Qt::CaseInsensitive) == 0)) {
+    calculateEDT(VanDerWaals, cubeResolution);
+    return true;
+  } else if (command.compare("renderSolventAccessible", Qt::CaseInsensitive) ==
+             0) {
+    calculateEDT(SolventAccessible, cubeResolution);
+    return true;
+  } else if (command.compare("renderSolventExcluded", Qt::CaseInsensitive) ==
+             0) {
+    calculateEDT(SolventExcluded, cubeResolution);
+    return true;
+  } else if ((command.compare("renderOrbital", Qt::CaseInsensitive) == 0) ||
+             (command.compare("renderMO", Qt::CaseInsensitive) == 0)) {
+    calculateQM(MolecularOrbital, index, beta, isoValue, cubeResolution);
+    return true;
+  } else if (command.compare("renderElectronDensity", Qt::CaseInsensitive) ==
+             0) {
+    calculateQM(ElectronDensity, index, beta, isoValue, cubeResolution);
+    return true;
+  } else if (command.compare("renderSpinDensity", Qt::CaseInsensitive) == 0) {
+    calculateQM(SpinDensity, index, beta, isoValue, cubeResolution);
+    return true;
+  }
+
+  return false;
 }
 
 void Surfaces::setMolecule(QtGui::Molecule* mol)
 {
+  if (m_molecule != nullptr) {
+    m_molecule->disconnect(this);
+  }
+
   if (mol->basisSet()) {
     m_basis = mol->basisSet();
   } else if (mol->cubes().size() != 0) {
@@ -111,6 +237,18 @@ void Surfaces::setMolecule(QtGui::Molecule* mol)
   m_mesh1 = nullptr;
   m_mesh2 = nullptr;
   m_molecule = mol;
+
+  if (m_molecule != nullptr) {
+    connect(m_molecule, SIGNAL(changed(uint)), SLOT(moleculeChanged(uint)));
+  }
+}
+
+void Surfaces::moleculeChanged(unsigned int changes)
+{
+  if (changes & Molecule::Added || changes & Molecule::Removed) {
+    m_cubes = m_molecule->cubes();
+    m_basis = m_molecule->basisSet();
+  }
 }
 
 QList<QAction*> Surfaces::actions() const
@@ -147,39 +285,47 @@ void Surfaces::surfacesActivated()
     m_dialog->setupBasis(m_basis->electronCount(),
                          m_basis->molecularOrbitalCount(), beta);
   }
+  // only show cubes from files so we don't duplicate orbitals
   if (m_cubes.size() > 0) {
     QStringList cubeNames;
-    for (auto & m_cube : m_cubes) {
-      cubeNames << m_cube->name().c_str();
+    for (auto* cube : m_cubes) {
+      if (cube->cubeType() == Core::Cube::Type::FromFile)
+        cubeNames << cube->name().c_str();
     }
     m_dialog->setupCubes(cubeNames);
   }
   m_dialog->setupSteps(m_molecule->coordinate3dCount());
 
-  const auto identifiers = Calc::ChargeManager::instance().identifiersForMolecule(*m_molecule);
+  const auto identifiers =
+    Calc::ChargeManager::instance().identifiersForMolecule(*m_molecule);
   std::set<std::pair<std::string, std::string>> chargeModels;
-  for (const auto &identifier: identifiers)
-    chargeModels.emplace(Calc::ChargeManager::instance().nameForModel(identifier), identifier);
+  for (const auto& identifier : identifiers)
+    chargeModels.emplace(
+      Calc::ChargeManager::instance().nameForModel(identifier), identifier);
   m_dialog->setupModels(chargeModels);
 
   m_dialog->show();
 }
 
-float Surfaces::resolution()
+float Surfaces::resolution(float specified)
 {
-  if (!m_dialog->automaticResolution())
+  if (specified != 0.0)
+    return specified;
+
+  if (m_dialog != nullptr && !m_dialog->automaticResolution())
     return m_dialog->resolution();
 
   float r = 0.02 * powf(m_molecule->atomCount(), 1.0f / 3.0f);
   float minimum = 0.05;
   float maximum = 0.5;
 
-  switch (m_dialog->surfaceType()) {
-    case SolventExcluded:
-      minimum = 0.1;
-      break;
-    default:
-      ;
+  if (m_dialog != nullptr) {
+    switch (m_dialog->surfaceType()) {
+      case SolventExcluded:
+        minimum = 0.1;
+        break;
+      default:;
+    }
   }
 
   r = std::max(minimum, std::min(maximum, r));
@@ -217,79 +363,95 @@ void Surfaces::calculateSurface()
   }
 }
 
-float inline square(float x) { return x * x; }
-
-void Surfaces::calculateEDT()
+float inline square(float x)
 {
+  return x * x;
+}
+
+void Surfaces::calculateEDT(Type type, float defaultResolution)
+{
+  if (type == Unknown && m_dialog != nullptr)
+    type = m_dialog->surfaceType();
+
+  if (!m_cube)
+    m_cube = m_molecule->addCube();
+
   QFuture future = QtConcurrent::run([=]() {
     double probeRadius = 0.0;
-    switch (m_dialog->surfaceType()) {
+    switch (type) {
       case VanDerWaals:
-          break;
+        m_cube->setCubeType(Core::Cube::Type::VdW);
+        break;
       case SolventAccessible:
+        m_cube->setCubeType(Core::Cube::Type::SolventAccessible);
       case SolventExcluded:
-          probeRadius = 1.4;
-          break;
+        probeRadius = 1.4;
+        m_cube->setCubeType(Core::Cube::Type::SolventExcluded);
+        break;
+      default:
+        break;
     }
 
     // first, make a list of all atom positions and radii
     Array<Vector3> atomPositions = m_molecule->atomPositions3d();
-    auto *atoms = new std::vector<std::pair<Vector3, double>>();
+    auto* atoms = new std::vector<std::pair<Vector3, double>>();
     double max_radius = probeRadius;
     QtGui::RWLayerManager layerManager;
     for (size_t i = 0; i < m_molecule->atomCount(); i++) {
       if (!layerManager.visible(m_molecule->layer(i)))
-        continue;
-      auto radius = Core::Elements::radiusVDW(m_molecule->atomicNumber(i)) + probeRadius;
+        continue; // ignore invisible atoms
+      auto radius =
+        Core::Elements::radiusVDW(m_molecule->atomicNumber(i)) + probeRadius;
       atoms->emplace_back(atomPositions[i], radius);
       if (radius > max_radius)
         max_radius = radius;
     }
 
     double padding = max_radius + probeRadius;
-    m_cube->setLimits(*m_molecule, resolution(), padding);
+    m_cube->setLimits(*m_molecule, resolution(defaultResolution), padding);
     m_cube->fill(-1.0);
 
-    const float res = resolution();
+    const float res = resolution(defaultResolution);
     const Vector3 min = m_cube->min();
-    const float mdist = probeRadius;
 
     // then, for each atom, set cubes around it up to a certain radius
-    QFuture innerFuture = QtConcurrent::map(*atoms, [=](std::pair<Vector3, double> &in) {
-      double startPosX = in.first(0) - in.second;
-      double endPosX = in.first(0) + in.second;
-      int startIndexX = (startPosX - min(0)) / res;
-      int endIndexX = (endPosX - min(0)) / res + 1;
-      for (int indexX = startIndexX; indexX < endIndexX; indexX++) {
-        double posX = indexX * res + min(0);
-        double radiusXsq = square(in.second) - square(posX - in.first(0));
-        if (radiusXsq < 0.0)
-          continue;
-        double radiusX = sqrt(radiusXsq);
-        double startPosY = in.first(1) - radiusX;
-        double endPosY = in.first(1) + radiusX;
-        int startIndexY = (startPosY - min(1)) / res;
-        int endIndexY = (endPosY - min(1)) / res + 1;
-        for (int indexY = startIndexY; indexY < endIndexY; indexY++) {
-          double posY = indexY * res + min(1);
-          double lengthXYsq = square(radiusX) - square(posY - in.first(1));
-          if (lengthXYsq < 0.0)
+    QFuture innerFuture =
+      QtConcurrent::map(*atoms, [=](std::pair<Vector3, double>& in) {
+        double startPosX = in.first(0) - in.second;
+        double endPosX = in.first(0) + in.second;
+        int startIndexX = (startPosX - min(0)) / res;
+        int endIndexX = (endPosX - min(0)) / res + 1;
+        for (int indexX = startIndexX; indexX < endIndexX; indexX++) {
+          double posX = indexX * res + min(0);
+          double radiusXsq = square(in.second) - square(posX - in.first(0));
+          if (radiusXsq < 0.0)
             continue;
-          double lengthXY = sqrt(lengthXYsq);
-          double startPosZ = in.first(2) - lengthXY;
-          double endPosZ = in.first(2) + lengthXY;
-          int startIndexZ = (startPosZ - min(2)) / res;
-          int endIndexZ = (endPosZ - min(2)) / res + 1;
-          m_cube->fillStripe(indexX, indexY, startIndexZ, endIndexZ - 1, 1.0f);
+          double radiusX = sqrt(radiusXsq);
+          double startPosY = in.first(1) - radiusX;
+          double endPosY = in.first(1) + radiusX;
+          int startIndexY = (startPosY - min(1)) / res;
+          int endIndexY = (endPosY - min(1)) / res + 1;
+          for (int indexY = startIndexY; indexY < endIndexY; indexY++) {
+            double posY = indexY * res + min(1);
+            double lengthXYsq = square(radiusX) - square(posY - in.first(1));
+            if (lengthXYsq < 0.0)
+              continue;
+            double lengthXY = sqrt(lengthXYsq);
+            double startPosZ = in.first(2) - lengthXY;
+            double endPosZ = in.first(2) + lengthXY;
+            int startIndexZ = (startPosZ - min(2)) / res;
+            int endIndexZ = (endPosZ - min(2)) / res + 1;
+            m_cube->fillStripe(indexX, indexY, startIndexZ, endIndexZ - 1,
+                               1.0f);
+          }
         }
-      }
-    });
-    
+      });
+
     innerFuture.waitForFinished();
   });
-  
+
   // SolventExcluded requires an extra pass
-  if (m_dialog->surfaceType() == SolventExcluded) {
+  if (type == SolventExcluded) {
     m_performEDTStepWatcher.setFuture(future);
   } else {
     m_displayMeshWatcher.setFuture(future);
@@ -301,14 +463,14 @@ void Surfaces::performEDTStep()
   QFuture future = QtConcurrent::run([=]() {
     const double probeRadius = 1.4;
     const double scaledProbeRadius = probeRadius / resolution();
-    
+
     // make a list of all "outside" cubes in contact with an "inside" cube
     // these are the only ones that can be "nearest" to an "inside" cube
     Array<Vector3> relativePositions;
     // also make a list of all "inside" cubes
-    auto *insideIndices = new std::vector<Vector3i>;
+    auto* insideIndices = new std::vector<Vector3i>;
     Vector3i size = m_cube->dimensions();
-    relativePositions.reserve(size(0) * size(1) * 4); // O(n^2)
+    relativePositions.reserve(size(0) * size(1) * 4);    // O(n^2)
     insideIndices->reserve(size(0) * size(1) * size(2)); // O(n^3)
     for (int z = 0; z < size(2); z++) {
       int zp = std::max(z - 1, 0);
@@ -323,31 +485,27 @@ void Surfaces::performEDTStep()
           }
           int xp = std::max(x - 1, 0);
           int xn = std::min(x + 1, size(0) - 1);
-          if (m_cube->value(xp, y, z) > 0.0
-            || m_cube->value(xn, y, z) > 0.0
-            || m_cube->value(x, yp, z) > 0.0
-            || m_cube->value(x, yn, z) > 0.0
-            || m_cube->value(x, y, zp) > 0.0
-            || m_cube->value(x, y, zn) > 0.0
-          ) {
+          if (m_cube->value(xp, y, z) > 0.0 || m_cube->value(xn, y, z) > 0.0 ||
+              m_cube->value(x, yp, z) > 0.0 || m_cube->value(x, yn, z) > 0.0 ||
+              m_cube->value(x, y, zp) > 0.0 || m_cube->value(x, y, zn) > 0.0) {
             relativePositions.push_back(Vector3(x, y, z));
           }
         }
       }
     }
-    
+
     // pass the list to a NeighborPerceiver so it's faster to look up
     NeighborPerceiver perceiver(relativePositions, scaledProbeRadius);
-    
+
     // now, exclude all "inside" cubes too close to any "outside" cube
-    thread_local Array<Index> *neighbors = nullptr;
-    QFuture innerFuture = QtConcurrent::map(*insideIndices, [=](Vector3i &in) {
+    thread_local Array<Index>* neighbors = nullptr;
+    QFuture innerFuture = QtConcurrent::map(*insideIndices, [=](Vector3i& in) {
       Vector3 pos = in.cast<double>();
       if (neighbors == nullptr)
         neighbors = new Array<Index>;
       perceiver.getNeighborsInclusiveInPlace(*neighbors, pos);
-      for (Index neighbor: *neighbors) {
-        const Vector3 &npos = relativePositions[neighbor];
+      for (Index neighbor : *neighbors) {
+        const Vector3& npos = relativePositions[neighbor];
         float distance = (npos - pos).norm();
         if (distance <= scaledProbeRadius) {
           m_cube->setValue(in(0), in(1), in(2), -1.0f);
@@ -355,18 +513,25 @@ void Surfaces::performEDTStep()
         }
       }
     });
-    
+
     innerFuture.waitForFinished();
   });
-  
+
   m_displayMeshWatcher.setFuture(future);
 }
 
-void Surfaces::calculateQM()
+void Surfaces::calculateQM(Type type, int index, bool beta, float isoValue,
+                           float defaultResolution)
 {
-  if (!m_basis || !m_dialog)
+  if (!m_basis)
     return; // nothing to do
 
+  if (m_dialog != nullptr) {
+    beta = m_dialog->beta(); // we're using the GUI
+  }
+
+  // TODO: check if we already calculated the requested cube
+
   // Reset state a little more frequently, minimal cost, avoid bugs.
   m_molecule->clearCubes();
   m_molecule->clearMeshes();
@@ -402,28 +567,45 @@ void Surfaces::calculateQM()
   if (!m_cube)
     m_cube = m_molecule->addCube();
 
-  Type type = m_dialog->surfaceType();
-  int index = m_dialog->surfaceIndex();
-  m_isoValue = m_dialog->isosurfaceValue();
-  m_cube->setLimits(*m_molecule, resolution(), 5.0);
+  if (type == Unknown)
+    type = m_dialog->surfaceType();
+
+  if (index == -1 && m_dialog != nullptr)
+    index = m_dialog->surfaceIndex();
+  if (isoValue == 0.0 && m_dialog != nullptr)
+    m_isoValue = m_dialog->isosurfaceValue();
+  else
+    m_isoValue = isoValue;
+  float cubeResolution = resolution(defaultResolution);
+  float padding = 5.0;
+  // TODO: allow extra padding for some molecules / properties
+  m_cube->setLimits(*m_molecule, cubeResolution, padding);
 
   QString progressText;
   if (type == ElectronDensity) {
     progressText = tr("Calculating electron density");
     m_cube->setName("Electron Density");
+    m_cube->setCubeType(Core::Cube::Type::ElectronDensity);
     if (dynamic_cast<GaussianSet*>(m_basis)) {
       m_gaussianConcurrent->calculateElectronDensity(m_cube);
     } else {
       m_slaterConcurrent->calculateElectronDensity(m_cube);
     }
-  }
-
-  else if (type == MolecularOrbital) {
+  } else if (type == SpinDensity) {
+    progressText = tr("Calculating spin density");
+    m_cube->setName("Spin Density");
+    m_cube->setCubeType(Core::Cube::Type::SpinDensity);
+    if (dynamic_cast<GaussianSet*>(m_basis)) {
+      m_gaussianConcurrent->calculateSpinDensity(m_cube);
+    } else {
+      m_slaterConcurrent->calculateSpinDensity(m_cube);
+    }
+  } else if (type == MolecularOrbital) {
     progressText = tr("Calculating molecular orbital %L1").arg(index);
     m_cube->setName("Molecular Orbital " + std::to_string(index + 1));
+    m_cube->setCubeType(Core::Cube::Type::MO);
     if (dynamic_cast<GaussianSet*>(m_basis)) {
-      m_gaussianConcurrent->calculateMolecularOrbital(m_cube, index,
-                                                      m_dialog->beta());
+      m_gaussianConcurrent->calculateMolecularOrbital(m_cube, index, beta);
     } else {
       m_slaterConcurrent->calculateMolecularOrbital(m_cube, index);
     }
@@ -464,14 +646,25 @@ void Surfaces::calculateQM()
   }
 }
 
-void Surfaces::calculateCube()
+void Surfaces::calculateCube(int index, float isoValue)
 {
-  if (!m_dialog || m_cubes.size() == 0)
+  if (m_cubes.size() == 0)
+    return;
+
+  if (index == -1 && m_dialog != nullptr)
+    index = m_dialog->surfaceIndex();
+  if (index < 0 || index >= static_cast<int>(m_cubes.size()))
     return;
 
   // check bounds
-  m_cube = m_cubes[m_dialog->surfaceIndex()];
-  m_isoValue = m_dialog->isosurfaceValue();
+  m_cube = m_cubes[index];
+  if (m_cube == nullptr)
+    return;
+
+  if (isoValue == 0.0 && m_dialog != nullptr)
+    m_isoValue = m_dialog->isosurfaceValue();
+  else
+    m_isoValue = isoValue;
   displayMesh();
 }
 
@@ -498,9 +691,10 @@ void Surfaces::displayMesh()
   if (!m_cube)
     return;
 
-  qDebug() << " running displayMesh";
-
-  m_smoothingPasses = m_dialog->smoothingPassesValue();
+  if (m_dialog != nullptr)
+    m_smoothingPasses = m_dialog->smoothingPassesValue();
+  else
+    m_smoothingPasses = 0;
 
   if (!m_mesh1)
     m_mesh1 = m_molecule->addMesh();
@@ -508,30 +702,42 @@ void Surfaces::displayMesh()
     m_meshGenerator1 = new QtGui::MeshGenerator;
     connect(m_meshGenerator1, SIGNAL(finished()), SLOT(meshFinished()));
   }
-  m_meshGenerator1->initialize(m_cube, m_mesh1, -m_isoValue, m_smoothingPasses);
+  m_meshGenerator1->initialize(m_cube, m_mesh1, m_isoValue, m_smoothingPasses);
 
-  // TODO - only do this if we're generating an orbital
-  //    and we need two meshes
-  //   How do we know? - likely ask the cube if it's an MO?
-  if (!m_mesh2)
-    m_mesh2 = m_molecule->addMesh();
-  if (!m_meshGenerator2) {
-    m_meshGenerator2 = new QtGui::MeshGenerator;
-    connect(m_meshGenerator2, SIGNAL(finished()), SLOT(meshFinished()));
+  bool isMO = false;
+  // if it's from a file we should "play it safe"
+  if (m_cube->cubeType() == Cube::Type::MO ||
+      m_cube->cubeType() == Cube::Type::FromFile) {
+    isMO = true;
+  }
+
+  if (isMO) {
+    if (!m_mesh2)
+      m_mesh2 = m_molecule->addMesh();
+    if (!m_meshGenerator2) {
+      m_meshGenerator2 = new QtGui::MeshGenerator;
+      connect(m_meshGenerator2, SIGNAL(finished()), SLOT(meshFinished()));
+    }
+    m_meshGenerator2->initialize(m_cube, m_mesh2, -m_isoValue,
+                                 m_smoothingPasses, true);
   }
-  m_meshGenerator2->initialize(m_cube, m_mesh2, m_isoValue, m_smoothingPasses, true);
 
   // Start the mesh generation - this needs an improved mutex with a read lock
   // to function as expected. Write locks are exclusive, read locks can have
   // many read locks but no write lock.
   m_meshGenerator1->start();
-  m_meshGenerator2->start();
+  if (isMO)
+    m_meshGenerator2->start();
 
   // Track how many meshes are left to show.
-  m_meshesLeft = 2;
+  if (isMO)
+    m_meshesLeft = 2;
+  else
+    m_meshesLeft = 1;
 }
 
-Core::Color3f Surfaces::chargeGradient(double value, double clamp, ColormapType colormap) const
+Core::Color3f Surfaces::chargeGradient(double value, double clamp,
+                                       ColormapType colormap) const
 {
   // okay, typically color scales have blue at the bottom, red at the top.
   // so we need to invert, so blue is positive charge, red is negative charge.
@@ -585,27 +791,33 @@ void Surfaces::colorMeshByPotential()
 {
   const auto model = m_dialog->colorModel().toStdString();
   const auto colormap = getColormapFromString(m_dialog->colormapName());
-  
+
   const auto positionsf = m_mesh1->vertices();
+  if (positionsf.empty())
+    return;
+
   Core::Array<Vector3> positions(positionsf.size());
   std::transform(positionsf.begin(), positionsf.end(), positions.begin(),
-    [](const Vector3f &pos) { return pos.cast<double>(); }
-  );
-  const auto potentials = Calc::ChargeManager::instance().potentials(model, *m_molecule, positions);
-  
+                 [](const Vector3f& pos) { return pos.cast<double>(); });
+  const auto potentials =
+    Calc::ChargeManager::instance().potentials(model, *m_molecule, positions);
+
   double minPotential = *std::min_element(potentials.begin(), potentials.end());
   double maxPotential = *std::max_element(potentials.begin(), potentials.end());
-  double clamp = std::max(std::abs(minPotential), std::abs(minPotential));
-  
+  double clamp = std::max(std::abs(minPotential), std::abs(maxPotential));
+
   Core::Array<Core::Color3f> colors(positions.size());
   for (size_t i = 0; i < potentials.size(); i++)
     colors[i] = chargeGradient(potentials[i], clamp, colormap);
-  
+
   m_mesh1->setColors(colors);
 }
 
 void Surfaces::colorMesh()
 {
+  if (m_dialog == nullptr)
+    return;
+
   switch (m_dialog->colorProperty()) {
     case None:
       break;
@@ -620,20 +832,24 @@ void Surfaces::meshFinished()
   --m_meshesLeft;
   if (m_meshesLeft == 0) {
     colorMesh();
+
+    // finished, so request to enable the mesh display type
+    QStringList displayTypes;
+    displayTypes << tr("Meshes");
+    requestActiveDisplayTypes(displayTypes);
+
     if (m_recordingMovie) {
       // Move to the next frame.
       qDebug() << "Let's get to the next frame…";
       m_molecule->emitChanged(QtGui::Molecule::Added);
       movieFrame();
     } else {
-      m_dialog->reenableCalculateButton();
-
-      qDebug() << " mesh finished";
+      if (m_dialog != nullptr)
+        m_dialog->reenableCalculateButton();
 
       m_molecule->emitChanged(QtGui::Molecule::Added);
     }
   }
-  // TODO: enable the mesh display type
 }
 
 void Surfaces::recordMovie()
@@ -707,7 +923,8 @@ void Surfaces::movieFrame()
   if (QOpenGLFramebufferObject::hasOpenGLFramebufferObjects()) {
     exportImage = glWidget->grabFramebuffer();
   } else {
-    QPixmap pixmap = QPixmap::grabWindow(glWidget->winId());
+    auto* screen = QGuiApplication::primaryScreen();
+    auto pixmap = screen->grabWindow(glWidget->winId());
     exportImage = pixmap.toImage();
   }
 
@@ -801,4 +1018,4 @@ void Surfaces::movieFrame()
   }
 }
 
-} // namespace Avogadro
+} // namespace Avogadro::QtPlugins
