@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2015 Marcus Johansson <mcodev31@gmail.com>
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #ifndef AVOGADRO_QTPLUGINS_SYMMETRYSCENE_H
@@ -35,7 +24,7 @@ public:
   explicit SymmetryScene(QObject* parent = nullptr);
   ~SymmetryScene() override;
 
-  void process(const Core::Molecule& molecule,
+  void process(const QtGui::Molecule& molecule,
                Rendering::GroupNode& node) override;
 
   void processEditable(const QtGui::RWMolecule& molecule,
@@ -50,7 +39,7 @@ public:
 
   bool isEnabled() const override;
 
-  bool isActiveLayerEnabled() const;
+  bool isActiveLayerEnabled() const override;
 
   void setEnabled(bool enable) override;
 
