@@ -11,8 +11,7 @@
 #include <avogadro/rendering/groupnode.h>
 #include <avogadro/rendering/spheregeometry.h>
 
-namespace Avogadro {
-namespace QtPlugins {
+namespace Avogadro::QtPlugins {
 
 using Core::Elements;
 using QtGui::PluginLayerManager;
@@ -31,9 +30,9 @@ void VanDerWaals::process(const QtGui::Molecule& molecule,
                           Rendering::GroupNode& node)
 {
   // Add a sphere node to contain all of the VdW spheres.
-  GeometryNode* geometry = new GeometryNode;
+  auto* geometry = new GeometryNode;
   node.addChild(geometry);
-  SphereGeometry* spheres = new SphereGeometry;
+  auto* spheres = new SphereGeometry;
   spheres->identifier().molecule = &molecule;
   spheres->identifier().type = Rendering::AtomType;
   auto selectedSpheres = new SphereGeometry;
@@ -50,7 +49,7 @@ void VanDerWaals::process(const QtGui::Molecule& molecule,
     unsigned char atomicNumber = atom.atomicNumber();
 
     Vector3ub color = atom.color();
-    float radius = static_cast<float>(Elements::radiusVDW(atomicNumber));
+    auto radius = static_cast<float>(Elements::radiusVDW(atomicNumber));
     spheres->addSphere(atom.position3d().cast<float>(), color, radius, i);
     if (atom.selected()) {
       color = Vector3ub(0, 0, 255);
@@ -61,5 +60,4 @@ void VanDerWaals::process(const QtGui::Molecule& molecule,
   }
 }
 
-} // namespace QtPlugins
 } // namespace Avogadro
