@@ -11,10 +11,10 @@
 
 #include <iostream>
 
-using std::vector;
-using std::string;
 using std::cout;
 using std::endl;
+using std::string;
+using std::vector;
 
 namespace Avogadro::QuantumIO {
 
@@ -22,16 +22,12 @@ using Core::Atom;
 using Core::BasisSet;
 using Core::GaussianSet;
 using Core::Rhf;
-using Core::Uhf;
 using Core::Rohf;
+using Core::Uhf;
 
-GaussianFchk::GaussianFchk() : m_scftype(Rhf)
-{
-}
+GaussianFchk::GaussianFchk() : m_scftype(Rhf) {}
 
-GaussianFchk::~GaussianFchk()
-{
-}
+GaussianFchk::~GaussianFchk() {}
 
 std::vector<std::string> GaussianFchk::fileExtensions() const
 {
@@ -61,8 +57,20 @@ bool GaussianFchk::read(std::istream& in, Core::Molecule& molecule)
                             m_aPos[i + 1] * BOHR_TO_ANGSTROM,
                             m_aPos[i + 2] * BOHR_TO_ANGSTROM));
   }
+
+  if (m_frequencies.size() > 0 &&
+      m_frequencies.size() == m_vibDisplacements.size() &&
+      m_frequencies.size() == m_IRintensities.size()) {
+    molecule.setVibrationFrequencies(m_frequencies);
+    molecule.setVibrationIRIntensities(m_IRintensities);
+    molecule.setVibrationLx(m_vibDisplacements);
+    if (m_RamanIntensities.size())
+      molecule.setVibrationRamanIntensities(m_RamanIntensities);
+  }
+
   // Do simple bond perception.
   molecule.perceiveBondsSimple();
+  molecule.perceiveBondOrders();
   molecule.setBasisSet(basis);
   basis->setMolecule(&molecule);
   load(basis);
@@ -87,6 +95,7 @@ void GaussianFchk::processLine(std::istream& in)
 
   string tmp = line.substr(43);
   vector<string> list = Core::split(tmp, ' ');
+  std::vector<double> tmpVec;
 
   // Big switch statement checking for various things we are interested in
   if (Core::contains(key, "RHF")) {
@@ -94,7 +103,11 @@ void GaussianFchk::processLine(std::istream& in)
   } else if (Core::contains(key, "UHF")) {
     m_scftype = Uhf;
   } else if (key == "Number of atoms" && list.size() > 1) {
-    cout << "Number of atoms = " << Core::lexicalCast<int>(list[1]) << endl;
+    m_numAtoms = Core::lexicalCast<int>(list[1]);
+  } else if (key == "Charge" && list.size() > 1) {
+    m_charge = Core::lexicalCast<signed char>(list[1]);
+  } else if (key == "Multiplicity" && list.size() > 1) {
+    m_spin = Core::lexicalCast<char>(list[1]);
   } else if (key == "Number of electrons" && list.size() > 1) {
     m_electrons = Core::lexicalCast<int>(list[1]);
   } else if (key == "Number of alpha electrons" && list.size() > 1) {
@@ -103,13 +116,11 @@ void GaussianFchk::processLine(std::istream& in)
     m_electronsBeta = Core::lexicalCast<int>(list[1]);
   } else if (key == "Number of basis functions" && list.size() > 1) {
     m_numBasisFunctions = Core::lexicalCast<int>(list[1]);
-    cout << "Number of basis functions = " << m_numBasisFunctions << endl;
+    // cout << "Number of basis functions = " << m_numBasisFunctions << endl;
   } else if (key == "Atomic numbers" && list.size() > 2) {
     m_aNums = readArrayI(in, Core::lexicalCast<int>(list[2]));
     if (static_cast<int>(m_aNums.size()) != Core::lexicalCast<int>(list[2]))
       cout << "Reading atomic numbers failed.\n";
-    else
-      cout << "Reading atomic numbers succeeded.\n";
   }
   // Now we get to the meat of it - coordinates of the atoms
   else if (key == "Current cartesian coordinates" && list.size() > 2) {
@@ -133,15 +144,16 @@ void GaussianFchk::processLine(std::istream& in)
   } else if (key == "Alpha Orbital Energies") {
     if (m_scftype == Rhf) {
       m_orbitalEnergy = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-      cout << "MO energies, n = " << m_orbitalEnergy.size() << endl;
+      // cout << "MO energies, n = " << m_orbitalEnergy.size() << endl;
     } else if (m_scftype == Uhf) {
       m_alphaOrbitalEnergy =
         readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-      cout << "Alpha MO energies, n = " << m_alphaOrbitalEnergy.size() << endl;
+      // cout << "Alpha MO energies, n = " << m_alphaOrbitalEnergy.size() <<
+      // endl;
     }
   } else if (key == "Beta Orbital Energies") {
     if (m_scftype != Uhf) {
-      cout << "UHF detected. Reassigning Alpha properties." << endl;
+      // cout << "UHF detected. Reassigning Alpha properties." << endl;
       m_scftype = Uhf;
       m_alphaOrbitalEnergy = m_orbitalEnergy;
       m_orbitalEnergy = vector<double>();
@@ -151,37 +163,63 @@ void GaussianFchk::processLine(std::istream& in)
     }
 
     m_betaOrbitalEnergy = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-    cout << "Beta MO energies, n = " << m_betaOrbitalEnergy.size() << endl;
+    // cout << "Beta MO energies, n = " << m_betaOrbitalEnergy.size() << endl;
   } else if (key == "Alpha MO coefficients" && list.size() > 2) {
     if (m_scftype == Rhf) {
       m_MOcoeffs = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-      if (static_cast<int>(m_MOcoeffs.size()) ==
-          Core::lexicalCast<int>(list[2]))
-        cout << "MO coefficients, n = " << m_MOcoeffs.size() << endl;
     } else if (m_scftype == Uhf) {
       m_alphaMOcoeffs = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-      if (static_cast<int>(m_alphaMOcoeffs.size()) ==
-          Core::lexicalCast<int>(list[2]))
-        cout << "Alpha MO coefficients, n = " << m_alphaMOcoeffs.size() << endl;
     } else {
       cout << "Error, alpha MO coefficients, n = " << m_MOcoeffs.size() << endl;
     }
   } else if (key == "Beta MO coefficients" && list.size() > 2) {
     m_betaMOcoeffs = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
-    if (static_cast<int>(m_betaMOcoeffs.size()) ==
-        Core::lexicalCast<int>(list[2]))
-      cout << "Beta MO coefficients, n = " << m_betaMOcoeffs.size() << endl;
   } else if (key == "Total SCF Density" && list.size() > 2) {
-    if (readDensityMatrix(in, Core::lexicalCast<int>(list[2]), 16))
-      cout << "SCF density matrix read in " << m_density.rows() << endl;
-    else
+    if (!readDensityMatrix(in, Core::lexicalCast<int>(list[2]), 16))
       cout << "Error reading in the SCF density matrix.\n";
   } else if (key == "Spin SCF Density" && list.size() > 2) {
-    if (readSpinDensityMatrix(in, Core::lexicalCast<int>(list[2]), 16))
-      cout << "SCF spin density matrix read in " << m_spinDensity.rows()
-           << endl;
-    else
+    if (!readSpinDensityMatrix(in, Core::lexicalCast<int>(list[2]), 16))
       cout << "Error reading in the SCF spin density matrix.\n";
+  } else if (key == "Number of Normal Modes" && list.size() > 1) {
+    m_normalModes = Core::lexicalCast<int>(list[1]);
+  } else if (key == "Vib-E2" && list.size() > 2) {
+    m_frequencies.clear();
+    m_IRintensities.clear();
+    m_RamanIntensities.clear();
+
+    unsigned threeN = m_numAtoms * 3; // degrees of freedom
+    tmpVec = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
+
+    // read in the first 3N-6 elements as frequencies
+    for (unsigned int i = 0; i < m_normalModes; ++i) {
+      m_frequencies.push_back(tmpVec[i]);
+    }
+    // skip to after threeN elements then read IR intensities
+    for (unsigned int i = threeN; i < threeN + m_normalModes; ++i) {
+      m_IRintensities.push_back(tmpVec[i]);
+    }
+    // now check if we have Raman intensities
+    if (tmpVec[threeN + m_normalModes] != 0.0) {
+      for (unsigned int i = threeN + m_normalModes;
+           i < threeN + 2 * m_normalModes; ++i) {
+        m_RamanIntensities.push_back(tmpVec[i]);
+      }
+    }
+  } else if (key == "Vib-Modes" && list.size() > 2) {
+    tmpVec = readArrayD(in, Core::lexicalCast<int>(list[2]), 16);
+    m_vibDisplacements.clear();
+    if (tmpVec.size() == m_numAtoms * 3 * m_normalModes) {
+      for (unsigned int i = 0; i < m_normalModes; ++i) {
+        Core::Array<Vector3> mode;
+        for (unsigned int j = 0; j < m_numAtoms; ++j) {
+          Vector3 v(tmpVec[i * m_numAtoms * 3 + j * 3],
+                    tmpVec[i * m_numAtoms * 3 + j * 3 + 1],
+                    tmpVec[i * m_numAtoms * 3 + j * 3 + 2]);
+          mode.push_back(v);
+        }
+        m_vibDisplacements.push_back(mode);
+      }
+    }
   }
 }
 
@@ -273,10 +311,20 @@ void GaussianFchk::load(GaussianSet* basis)
       basis->setMolecularOrbitals(m_alphaMOcoeffs, BasisSet::Alpha);
     if (m_betaMOcoeffs.size())
       basis->setMolecularOrbitals(m_betaMOcoeffs, BasisSet::Beta);
+
     if (m_density.rows())
       basis->setDensityMatrix(m_density);
     if (m_spinDensity.rows())
       basis->setSpinDensityMatrix(m_spinDensity);
+
+    if (m_orbitalEnergy.size()) // restricted calculation
+      basis->setMolecularOrbitalEnergy(m_orbitalEnergy);
+    else {
+      if (m_alphaOrbitalEnergy.size())
+        basis->setMolecularOrbitalEnergy(m_alphaOrbitalEnergy, BasisSet::Alpha);
+      if (m_betaOrbitalEnergy.size())
+        basis->setMolecularOrbitalEnergy(m_betaOrbitalEnergy, BasisSet::Beta);
+    }
   } else {
     cout << "Basis set is not valid!\n";
   }
@@ -298,7 +346,7 @@ vector<int> GaussianFchk::readArrayI(std::istream& in, unsigned int n)
       return tmp;
 
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list) {
+    for (auto& i : list) {
       if (tmp.size() >= n) {
         cout << "Too many variables read in. File may be inconsistent. "
              << tmp.size() << " of " << n << endl;
@@ -333,7 +381,7 @@ vector<double> GaussianFchk::readArrayD(std::istream& in, unsigned int n,
 
     if (width == 0) { // we can split by spaces
       vector<string> list = Core::split(line, ' ');
-      for (auto & i : list) {
+      for (auto& i : list) {
         if (tmp.size() >= n) {
           cout << "Too many variables read in. File may be inconsistent. "
                << tmp.size() << " of " << n << endl;
@@ -390,7 +438,7 @@ bool GaussianFchk::readDensityMatrix(std::istream& in, unsigned int n,
 
     if (width == 0) { // we can split by spaces
       vector<string> list = Core::split(line, ' ');
-      for (auto & k : list) {
+      for (auto& k : list) {
         if (cnt >= n) {
           cout << "Too many variables read in. File may be inconsistent. "
                << cnt << " of " << n << endl;
@@ -466,7 +514,7 @@ bool GaussianFchk::readSpinDensityMatrix(std::istream& in, unsigned int n,
 
     if (width == 0) { // we can split by spaces
       vector<string> list = Core::split(line, ' ');
-      for (auto & k : list) {
+      for (auto& k : list) {
         if (cnt >= n) {
           cout << "Too many variables read in. File may be inconsistent. "
                << cnt << " of " << n << endl;
@@ -561,4 +609,4 @@ void GaussianFchk::outputAll()
     cout << endl << endl;
   }
 }
-}
+} // namespace Avogadro::QuantumIO
