@@ -11,10 +11,10 @@
 
 #include <iostream>
 
-using std::vector;
-using std::string;
 using std::cout;
 using std::endl;
+using std::string;
+using std::vector;
 
 namespace Avogadro::QuantumIO {
 
@@ -26,9 +26,7 @@ MoldenFile::MoldenFile()
 {
 }
 
-MoldenFile::~MoldenFile()
-{
-}
+MoldenFile::~MoldenFile() {}
 
 std::vector<std::string> MoldenFile::fileExtensions() const
 {
@@ -60,6 +58,7 @@ bool MoldenFile::read(std::istream& in, Core::Molecule& molecule)
   }
   // Do simple bond perception.
   molecule.perceiveBondsSimple();
+  molecule.perceiveBondOrders();
   molecule.setBasisSet(basis);
   basis->setMolecule(&molecule);
   load(basis);
@@ -160,6 +159,9 @@ void MoldenFile::processLine(std::istream& in)
           list = Core::split(line, ' ');
           if (Core::contains(line, "Occup"))
             m_electrons += Core::lexicalCast<int>(list[1]);
+          else if (Core::contains(line, "Ene"))
+            m_orbitalEnergy.push_back(Core::lexicalCast<double>(list[1]));
+          // TODO: track alpha beta spin
         }
 
         // Parse the molecular orbital coefficients.
@@ -223,6 +225,8 @@ void MoldenFile::load(GaussianSet* basis)
   // Now to load in the MO coefficients
   if (m_MOcoeffs.size())
     basis->setMolecularOrbitals(m_MOcoeffs);
+  if (m_orbitalEnergy.size())
+    basis->setMolecularOrbitalEnergy(m_orbitalEnergy);
 }
 
 void MoldenFile::outputAll()
@@ -237,4 +241,4 @@ void MoldenFile::outputAll()
     cout << m_MOcoeff << "\t";
   cout << endl;
 }
-}
+} // namespace Avogadro::QuantumIO
