@@ -11,23 +11,19 @@
 
 #include <iostream>
 
-using std::vector;
-using std::string;
 using std::cout;
 using std::endl;
+using std::string;
+using std::vector;
 
 namespace Avogadro::QuantumIO {
 
 using Core::Atom;
 using Core::SlaterSet;
 
-MopacAux::MopacAux()
-{
-}
+MopacAux::MopacAux() : m_electrons(0) {}
 
-MopacAux::~MopacAux()
-{
-}
+MopacAux::~MopacAux() {}
 
 std::vector<std::string> MopacAux::fileExtensions() const
 {
@@ -56,9 +52,41 @@ bool MopacAux::read(std::istream& in, Core::Molecule& molecule)
   }
   // Do simple bond perception.
   molecule.perceiveBondsSimple();
+  molecule.perceiveBondOrders();
   molecule.setBasisSet(basis);
   basis->setMolecule(&molecule);
   load(basis);
+
+  // check if there is vibrational data
+  if (m_frequencies.size() > 0) {
+    // convert the std::vector to Array
+    Core::Array<double> frequencies(m_frequencies.size());
+    for (unsigned int i = 0; i < m_frequencies.size(); ++i)
+      frequencies[i] = m_frequencies[i];
+    molecule.setVibrationFrequencies(frequencies);
+
+    // convert the std::vector to Array
+    Core::Array<double> intensities(m_frequencies.size(), 0.0);
+    if (m_irIntensities.size() == m_frequencies.size()) {
+      for (unsigned int i = 0; i < m_irIntensities.size(); ++i)
+        intensities[i] = m_irIntensities[i];
+    }
+    molecule.setVibrationIRIntensities(intensities);
+
+    // wrap the normal modes into a vector of vectors
+    Core::Array<Core::Array<Vector3>> normalModes;
+    Core::Array<Vector3> normalMode;
+    Index atomCount = molecule.atomCount();
+    for (unsigned int i = 0; i < m_normalModes.size(); ++i) {
+      normalMode.push_back(m_normalModes[i]);
+      if (i % atomCount == 0 && normalMode.size() > 0) {
+        normalModes.push_back(normalMode);
+        normalMode.clear();
+      }
+    }
+    molecule.setVibrationLx(normalModes);
+  }
+
   return true;
 }
 
@@ -80,7 +108,7 @@ void MopacAux::processLine(std::istream& in)
     int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 4));
     cout << "Number of atomic orbitals = " << tmp << endl;
     m_atomIndex = readArrayI(in, tmp);
-    for (int & i : m_atomIndex)
+    for (int& i : m_atomIndex)
       --i;
   } else if (Core::contains(key, "ATOM_SYMTYPE")) {
     int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 4));
@@ -120,6 +148,15 @@ void MopacAux::processLine(std::istream& in)
     int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 6));
     cout << "Size of lower half triangle of density matrix = " << tmp << endl;
     readDensityMatrix(in, tmp);
+  } else if (Core::contains(key, "VIB._FREQ")) {
+    int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 6));
+    readVibrationFrequencies(in, tmp);
+  } else if (Core::contains(key, "VIB._T_DIP")) {
+    int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 6));
+    readVibrationIntensities(in, tmp);
+  } else if (Core::contains(key, "NORMAL_MODES")) {
+    int tmp = Core::lexicalCast<int>(key.substr(key.find('[') + 1, 6));
+    readNormalModes(in, tmp);
   }
 }
 
@@ -148,7 +185,7 @@ vector<int> MopacAux::readArrayElements(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list) {
+    for (auto& i : list) {
       tmp.push_back(
         static_cast<int>(Core::Elements::atomicNumberFromSymbol(i)));
     }
@@ -163,7 +200,7 @@ vector<int> MopacAux::readArrayI(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list)
+    for (auto& i : list)
       tmp.push_back(Core::lexicalCast<int>(i));
   }
   return tmp;
@@ -176,7 +213,7 @@ vector<double> MopacAux::readArrayD(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list)
+    for (auto& i : list)
       tmp.push_back(Core::lexicalCast<double>(i));
   }
   return tmp;
@@ -190,7 +227,7 @@ vector<int> MopacAux::readArraySym(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list) {
+    for (auto& i : list) {
       if (i == "S")
         type = SlaterSet::S;
       else if (i == "PX")
@@ -226,12 +263,33 @@ vector<Vector3> MopacAux::readArrayVec(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & i : list)
+    for (auto& i : list)
       ptr[cnt++] = Core::lexicalCast<double>(i);
   }
   return tmp;
 }
 
+bool MopacAux::readVibrationFrequencies(std::istream& in, unsigned int n)
+{
+  vector<double> tmp = readArrayD(in, n);
+  m_frequencies.insert(m_frequencies.end(), tmp.begin(), tmp.end());
+  return true;
+}
+
+bool MopacAux::readVibrationIntensities(std::istream& in, unsigned int n)
+{
+  vector<double> tmp = readArrayD(in, n);
+  m_irIntensities.insert(m_irIntensities.end(), tmp.begin(), tmp.end());
+  return true;
+}
+
+bool MopacAux::readNormalModes(std::istream& in, unsigned int n)
+{
+  vector<Vector3> tmp = readArrayVec(in, n);
+  m_normalModes.insert(m_normalModes.end(), tmp.begin(), tmp.end());
+  return true;
+}
+
 bool MopacAux::readOverlapMatrix(std::istream& in, unsigned int n)
 {
   m_overlap.resize(m_zeta.size(), m_zeta.size());
@@ -244,7 +302,7 @@ bool MopacAux::readOverlapMatrix(std::istream& in, unsigned int n)
   while (cnt < n) {
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & k : list) {
+    for (auto& k : list) {
       // m_overlap.part<Eigen::SelfAdjoint>()(i, j) = list.at(k).toDouble();
       m_overlap(i, j) = m_overlap(j, i) = Core::lexicalCast<double>(k);
       ++i;
@@ -269,7 +327,7 @@ bool MopacAux::readEigenVectors(std::istream& in, unsigned int n)
     string line;
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & k : list) {
+    for (auto& k : list) {
       m_eigenVectors(i, j) = Core::lexicalCast<double>(k);
       ++i;
       ++cnt;
@@ -295,7 +353,7 @@ bool MopacAux::readDensityMatrix(std::istream& in, unsigned int n)
   while (cnt < n) {
     getline(in, line);
     vector<string> list = Core::split(line, ' ');
-    for (auto & k : list) {
+    for (auto& k : list) {
       // m_overlap.part<Eigen::SelfAdjoint>()(i, j) = list.at(k).toDouble();
       m_density(i, j) = m_density(j, i) = Core::lexicalCast<double>(k);
       ++i;
@@ -323,4 +381,4 @@ void MopacAux::outputAll()
     cout << m_MOcoeff << "\t";
   cout << endl;
 }
-}
+} // namespace Avogadro::QuantumIO
