@@ -27,8 +27,25 @@ using Core::Array;
 GLRenderer::GLRenderer()
   : m_valid(false), m_textRenderStrategy(nullptr), m_center(Vector3f::Zero()),
     m_radius(20.0)
+#ifdef _3DCONNEXION
+    ,
+    m_drawIcon(false), m_iconData(nullptr), m_iconWidth(0u), m_iconHeight(0u),
+    m_iconPosition(Eigen::Vector3f::Zero())
+#endif
 {
   m_overlayCamera.setIdentity();
+
+  float aspectRatio = static_cast<float>(m_camera.width()) /
+                      static_cast<float>(m_camera.height());
+  float distance = m_camera.distance(m_center);
+  float offset = distance + m_radius;
+  m_perspectiveFrustum = {
+    -aspectRatio, aspectRatio, -1.0f, 1.0f, 2.0f, offset
+  };
+  m_orthographicFrustum = {
+    -5.0f * aspectRatio, 5.0f * aspectRatio, -5.0f, 5.0f, -offset, offset
+  };
+
 }
 
 GLRenderer::~GLRenderer()
@@ -39,7 +56,7 @@ GLRenderer::~GLRenderer()
 void GLRenderer::initialize()
 {
   GLenum result = glewInit();
-  m_valid = (result == GLEW_OK);
+  m_valid = (result == GLEW_OK || result == GLEW_ERROR_NO_GLX_DISPLAY);
   if (!m_valid) {
     m_error += "GLEW could not be initialized.\n";
     return;
@@ -50,6 +67,8 @@ void GLRenderer::initialize()
     m_valid = false;
     return;
   }
+
+  m_solidPipeline.initialize();
 }
 
 void GLRenderer::resize(int width, int height)
@@ -60,6 +79,12 @@ void GLRenderer::resize(int width, int height)
   glViewport(0, 0, static_cast<GLint>(width), static_cast<GLint>(height));
   m_camera.setViewport(width, height);
   m_overlayCamera.setViewport(width, height);
+  m_solidPipeline.resize(width, height);
+}
+
+void GLRenderer::setPixelRatio(float ratio)
+{
+  m_solidPipeline.setPixelRatio(ratio);
 }
 
 void GLRenderer::render()
@@ -73,11 +98,17 @@ void GLRenderer::render()
   applyProjection();
 
   GLRenderVisitor visitor(m_camera, m_textRenderStrategy);
-  // Setup for opaque geometry
-  visitor.setRenderPass(OpaquePass);
+  // Setup for solid geometry
+  m_solidPipeline.begin();
+  visitor.setRenderPass(SolidPass);
   glEnable(GL_DEPTH_TEST);
   glDisable(GL_BLEND);
   m_scene.rootNode().accept(visitor);
+  m_solidPipeline.end();
+
+  // Setup for opaque geometry
+  visitor.setRenderPass(OpaquePass);
+  m_scene.rootNode().accept(visitor);
 
   // Setup for transparent geometry
   visitor.setRenderPass(TranslucentPass);
@@ -103,6 +134,24 @@ void GLRenderer::render()
   visitor.setCamera(m_overlayCamera);
   glDisable(GL_DEPTH_TEST);
   m_scene.rootNode().accept(visitor);
+
+#ifdef _3DCONNEXION
+  if (m_drawIcon && (m_iconData != nullptr)) {
+    glPushMatrix();
+    Eigen::Vector4f pivotPosition =
+      m_camera.projection().matrix() * m_camera.modelView().matrix() *
+      Eigen::Vector4f(m_iconPosition.x(), m_iconPosition.y(),
+                      m_iconPosition.z(), 1.0);
+    pivotPosition /= pivotPosition.w();
+    glRasterPos3d(pivotPosition.x(), pivotPosition.y(), pivotPosition.z());
+    glPixelZoom(1.0f, -1.0f);
+    glBitmap(0.0f, 0.0f, 0.0f, 0.0f, -static_cast<float>(m_iconWidth >> 1),
+             static_cast<float>(m_iconHeight >> 1), NULL);
+    glDrawPixels(m_iconWidth, m_iconHeight, GL_BGRA_EXT, GL_UNSIGNED_BYTE,
+                 m_iconData);
+    glPopMatrix();
+  }
+#endif
 }
 
 void GLRenderer::resetCamera()
@@ -155,16 +204,28 @@ void GLRenderer::setTextRenderStrategy(TextRenderStrategy* tren)
 void GLRenderer::applyProjection()
 {
   float distance = m_camera.distance(m_center);
+  float aspectRatio = static_cast<float>(m_camera.width()) /
+                      static_cast<float>(m_camera.height());
   if (m_camera.projectionType() == Perspective) {
-    m_camera.calculatePerspective(40.0f, std::max(2.0f, distance - m_radius),
-                                  distance + m_radius);
+    m_perspectiveFrustum[0] = m_perspectiveFrustum[2] * aspectRatio;
+    m_perspectiveFrustum[1] = m_perspectiveFrustum[3] * aspectRatio;
+    m_perspectiveFrustum[5] = distance + m_radius;
+    m_camera.calculatePerspective(
+      m_perspectiveFrustum[0], m_perspectiveFrustum[1], m_perspectiveFrustum[2],
+      m_perspectiveFrustum[3], m_perspectiveFrustum[4],
+      m_perspectiveFrustum[5]);
   } else {
     // Renders the orthographic projection of the molecule
-    const double halfHeight = m_radius;
-    const double halfWidth = halfHeight * m_camera.width() / m_camera.height();
-    m_camera.calculateOrthographic(
-      -halfWidth, halfWidth, -halfHeight, halfHeight,
-      std::max(2.0f, distance - m_radius), distance + m_radius);
+    m_orthographicFrustum[0] = m_orthographicFrustum[2] * aspectRatio;
+    m_orthographicFrustum[1] = m_orthographicFrustum[3] * aspectRatio;
+    m_orthographicFrustum[5] = distance + m_radius;
+    m_orthographicFrustum[4] = -m_orthographicFrustum[5];
+    m_camera.calculateOrthographic(m_orthographicFrustum[0],  // L
+                                   m_orthographicFrustum[1],  // R
+                                   m_orthographicFrustum[2],  // B
+                                   m_orthographicFrustum[3],  // T
+                                   m_orthographicFrustum[4],  // N
+                                   m_orthographicFrustum[5]); // F
   }
   m_overlayCamera.calculateOrthographic(
     0.f, static_cast<float>(m_overlayCamera.width()), 0.f,
@@ -244,6 +305,16 @@ Array<Identifier> GLRenderer::hits(const GroupNode* group,
   return result;
 }
 
+float GLRenderer::hit(const Vector3f& rayOrigin, const Vector3f& rayEnd,
+                      const Vector3f& rayDirection) const
+{
+  std::multimap<float, Identifier> results =
+    hits(&m_scene.rootNode(), rayOrigin, rayEnd, rayDirection);
+  if (results.size())
+    return results.begin()->first;
+  return std::numeric_limits<float>::max();
+}
+
 Array<Identifier> GLRenderer::hits(int x1, int y1, int x2, int y2) const
 {
   // Figure out where the corners of our rectangle are.
