@@ -1,17 +1,6 @@
 /******************************************************************************
-
   This source file is part of the Avogadro project.
-
-  Copyright 2013 Kitware, Inc.
-
-  This source code is released under the New BSD License, (the "License").
-
-  Unless required by applicable law or agreed to in writing, software
-  distributed under the License is distributed on an "AS IS" BASIS,
-  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-  See the License for the specific language governing permissions and
-  limitations under the License.
-
+  This source code is released under the 3-Clause BSD License, (see "LICENSE").
 ******************************************************************************/
 
 #include "glrendervisitor.h"
@@ -25,8 +14,7 @@
 #include "textlabel2d.h"
 #include "textlabel3d.h"
 
-namespace Avogadro {
-namespace Rendering {
+namespace Avogadro::Rendering {
 
 GLRenderVisitor::GLRenderVisitor(const Camera& camera_,
                                  const TextRenderStrategy* trs)
@@ -98,5 +86,4 @@ void GLRenderVisitor::visit(LineStripGeometry& geometry)
     geometry.render(m_camera);
 }
 
-} // End namespace Rendering
 } // End namespace Avogadro
